Class: Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceGcsBucketConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The identity to configure a GCS bucket.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiPlatformTenantresourceGcsBucketConfig

Returns a new instance of CloudAiPlatformTenantresourceGcsBucketConfig.



125
126
127
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adminsArray<String>

Corresponds to the JSON property admins

Returns:

  • (Array<String>)


91
92
93
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 91

def admins
  @admins
end

#bucket_nameString

Input/Output [Optional]. The name of a GCS bucket with max length of 63 chars. If not set, a random UUID will be generated as bucket name. Corresponds to the JSON property bucketName

Returns:

  • (String)


97
98
99
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 97

def bucket_name
  @bucket_name
end

#entity_nameString

Input/Output [Optional]. Only needed for per-entity tenant GCP resources. During Deprovision API, the on-demand deletion will only cover the tenant GCP resources with the specified entity name. Corresponds to the JSON property entityName

Returns:

  • (String)


104
105
106
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 104

def entity_name
  @entity_name
end

#kms_key_referenceString

Input/Output [Optional]. The KMS key name or the KMS grant name used for CMEK encryption. Only set this field when provisioning new GCS bucket. For existing GCS bucket, this field will be ignored because CMEK re-encryption is not supported. Corresponds to the JSON property kmsKeyReference

Returns:

  • (String)


112
113
114
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 112

def kms_key_reference
  @kms_key_reference
end

#ttl_daysFixnum

Input/Output [Optional]. Only needed when the content in bucket need to be garbage collected within some amount of days. Corresponds to the JSON property ttlDays

Returns:

  • (Fixnum)


118
119
120
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 118

def ttl_days
  @ttl_days
end

#viewersArray<String>

Input/Output [Required]. IAM roles (viewer/admin) put on the bucket. Corresponds to the JSON property viewers

Returns:

  • (Array<String>)


123
124
125
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 123

def viewers
  @viewers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



130
131
132
133
134
135
136
137
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 130

def update!(**args)
  @admins = args[:admins] if args.key?(:admins)
  @bucket_name = args[:bucket_name] if args.key?(:bucket_name)
  @entity_name = args[:entity_name] if args.key?(:entity_name)
  @kms_key_reference = args[:kms_key_reference] if args.key?(:kms_key_reference)
  @ttl_days = args[:ttl_days] if args.key?(:ttl_days)
  @viewers = args[:viewers] if args.key?(:viewers)
end