Class: Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceIamPolicyBinding

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The dynamic IAM bindings to be granted after tenant projects are created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiPlatformTenantresourceIamPolicyBinding

Returns a new instance of CloudAiPlatformTenantresourceIamPolicyBinding.



169
170
171
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membersArray<String>

Input/Output [Required]. The member service accounts with the roles above. Note: placeholders are same as the resource above. Corresponds to the JSON property members

Returns:

  • (Array<String>)


148
149
150
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 148

def members
  @members
end

#resourceString

Input/Output [Required]. The resource name that will be accessed by members, which also depends on resource_type. Note: placeholders are supported in resource names. For example, $tpn will be used when the tenant project number is not ready. Corresponds to the JSON property resource

Returns:

  • (String)


156
157
158
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 156

def resource
  @resource
end

#resource_typeString

Input/Output [Required]. Specifies the type of resource that will be accessed by members. Corresponds to the JSON property resourceType

Returns:

  • (String)


162
163
164
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 162

def resource_type
  @resource_type
end

#roleString

Input/Output [Required]. The role for members below. Corresponds to the JSON property role

Returns:

  • (String)


167
168
169
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 167

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



174
175
176
177
178
179
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 174

def update!(**args)
  @members = args[:members] if args.key?(:members)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @role = args[:role] if args.key?(:role)
end