Class: Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceInfraSpannerConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The configuration for a spanner database provisioning. Next ID: 8

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiPlatformTenantresourceInfraSpannerConfig

Returns a new instance of CloudAiPlatformTenantresourceInfraSpannerConfig.



231
232
233
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_database_optionsGoogle::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceInfraSpannerConfigCreateDatabaseOptions

The options to create a spanner database. KMS key access audit logging and AxT logging will be associated with the given resource name, resource type and service name. Please ensure to give right options to enable correct audit logging and AxT logging. Corresponds to the JSON property createDatabaseOptions



192
193
194
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 192

def create_database_options
  @create_database_options
end

#kms_key_referenceString

Input [Optional]. The KMS key name or the KMS grant name used for CMEK encryption. Only set this field when provisioning new Infra Spanner databases. For existing Infra Spanner databases, this field will be ignored because CMEK re-encryption is not supported. For example, projects//locations//keyRings// cryptoKeys/ Corresponds to the JSON property kmsKeyReference

Returns:

  • (String)


201
202
203
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 201

def kms_key_reference
  @kms_key_reference
end

#sdl_bundle_pathString

Input [Required]. The file path to the spanner SDL bundle. Corresponds to the JSON property sdlBundlePath

Returns:

  • (String)


206
207
208
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 206

def sdl_bundle_path
  @sdl_bundle_path
end

#spanner_borg_service_accountString

Input [Optional]. The spanner borg service account for delegating the kms key to. For example, spanner-infra-cmek-nonprod@system.gserviceaccount.com, for the nonprod universe. Corresponds to the JSON property spannerBorgServiceAccount

Returns:

  • (String)


213
214
215
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 213

def 
  @spanner_borg_service_account
end

#spanner_local_name_prefixString

Corresponds to the JSON property spannerLocalNamePrefix

Returns:

  • (String)


218
219
220
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 218

def spanner_local_name_prefix
  @spanner_local_name_prefix
end

#spanner_namespaceString

Corresponds to the JSON property spannerNamespace

Returns:

  • (String)


223
224
225
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 223

def spanner_namespace
  @spanner_namespace
end

#spanner_universeString

Input [Required]. Every database in Spanner can be identified by the following path name: /span//: Corresponds to the JSON property spannerUniverse

Returns:

  • (String)


229
230
231
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 229

def spanner_universe
  @spanner_universe
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



236
237
238
239
240
241
242
243
244
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 236

def update!(**args)
  @create_database_options = args[:create_database_options] if args.key?(:create_database_options)
  @kms_key_reference = args[:kms_key_reference] if args.key?(:kms_key_reference)
  @sdl_bundle_path = args[:sdl_bundle_path] if args.key?(:sdl_bundle_path)
  @spanner_borg_service_account = args[:spanner_borg_service_account] if args.key?(:spanner_borg_service_account)
  @spanner_local_name_prefix = args[:spanner_local_name_prefix] if args.key?(:spanner_local_name_prefix)
  @spanner_namespace = args[:spanner_namespace] if args.key?(:spanner_namespace)
  @spanner_universe = args[:spanner_universe] if args.key?(:spanner_universe)
end