Class: Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceInfraSpannerConfigCreateDatabaseOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The options to create a spanner database. KMS key access audit logging and AxT logging will be associated with the given resource name, resource type and service name. Please ensure to give right options to enable correct audit logging and AxT logging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiPlatformTenantresourceInfraSpannerConfigCreateDatabaseOptions

Returns a new instance of CloudAiPlatformTenantresourceInfraSpannerConfigCreateDatabaseOptions.



272
273
274
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cmek_cloud_resource_nameString

The cloud resource name for the CMEK encryption. For example, projects// locations/ Corresponds to the JSON property cmekCloudResourceName

Returns:

  • (String)


258
259
260
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 258

def cmek_cloud_resource_name
  @cmek_cloud_resource_name
end

#cmek_cloud_resource_typeString

The cloud resource type for the CMEK encryption. For example, contentwarehouse. googleapis.com/Location Corresponds to the JSON property cmekCloudResourceType

Returns:

  • (String)


264
265
266
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 264

def cmek_cloud_resource_type
  @cmek_cloud_resource_type
end

#cmek_service_nameString

The service name for the CMEK encryption. For example, contentwarehouse. googleapis.com Corresponds to the JSON property cmekServiceName

Returns:

  • (String)


270
271
272
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 270

def cmek_service_name
  @cmek_service_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



277
278
279
280
281
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 277

def update!(**args)
  @cmek_cloud_resource_name = args[:cmek_cloud_resource_name] if args.key?(:cmek_cloud_resource_name)
  @cmek_cloud_resource_type = args[:cmek_cloud_resource_type] if args.key?(:cmek_cloud_resource_type)
  @cmek_service_name = args[:cmek_service_name] if args.key?(:cmek_service_name)
end