Class: Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceTenantProjectConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The identity to configure a tenant project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiPlatformTenantresourceTenantProjectConfig

Returns a new instance of CloudAiPlatformTenantresourceTenantProjectConfig.



341
342
343
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_configGoogle::Apis::ContentwarehouseV1::GoogleApiServiceconsumermanagementV1BillingConfig

Describes the billing configuration for a new tenant project. Corresponds to the JSON property billingConfig



319
320
321
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 319

def billing_config
  @billing_config
end

#folderString

Input/Output [Required]. The folder that holds tenant projects and folder- level permissions will be automatically granted to all tenant projects under the folder. Note: the valid folder format is folders/folder_number`. Corresponds to the JSON propertyfolder`

Returns:

  • (String)


326
327
328
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 326

def folder
  @folder
end

#policy_bindingsArray<Google::Apis::ContentwarehouseV1::GoogleApiServiceconsumermanagementV1PolicyBinding>

Input/Output [Required]. The policy bindings that are applied to the tenant project during creation. At least one binding must have the role roles/owner with either user or group type. Corresponds to the JSON property policyBindings



333
334
335
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 333

def policy_bindings
  @policy_bindings
end

#servicesArray<String>

Input/Output [Required]. The API services that are enabled on the tenant project during creation. Corresponds to the JSON property services

Returns:

  • (Array<String>)


339
340
341
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 339

def services
  @services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



346
347
348
349
350
351
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 346

def update!(**args)
  @billing_config = args[:billing_config] if args.key?(:billing_config)
  @folder = args[:folder] if args.key?(:folder)
  @policy_bindings = args[:policy_bindings] if args.key?(:policy_bindings)
  @services = args[:services] if args.key?(:services)
end