Class: Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceTenantProjectResource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The tenant project and tenant resources. Next ID: 10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiPlatformTenantresourceTenantProjectResource

Returns a new instance of CloudAiPlatformTenantresourceTenantProjectResource.



410
411
412
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_sql_instancesArray<Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceCloudSqlInstanceConfig>

The CloudSQL instances that are provisioned under the tenant project. Corresponds to the JSON property cloudSqlInstances



361
362
363
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 361

def cloud_sql_instances
  @cloud_sql_instances
end

#gcs_bucketsArray<Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceGcsBucketConfig>

The GCS buckets that are provisioned under the tenant project. Corresponds to the JSON property gcsBuckets



366
367
368
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 366

def gcs_buckets
  @gcs_buckets
end

#iam_policy_bindingsArray<Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceIamPolicyBinding>

The dynamic IAM bindings that are granted under the tenant project. Note: this should only add new bindings to the project if they don't exist and the existing bindings won't be affected. Corresponds to the JSON property iamPolicyBindings



373
374
375
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 373

def iam_policy_bindings
  @iam_policy_bindings
end

#infra_spanner_configsArray<Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceInfraSpannerConfig>

The Infra Spanner databases that are provisioned under the tenant project. Note: this is an experimental feature. Corresponds to the JSON property infraSpannerConfigs



379
380
381
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 379

def infra_spanner_configs
  @infra_spanner_configs
end

#tagString

Input/Output [Required]. The tag that uniquely identifies a tenant project within a tenancy unit. Note: for the same tenant project tag, all tenant manager operations should be idempotent. Corresponds to the JSON property tag

Returns:

  • (String)


386
387
388
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 386

def tag
  @tag
end

#tenant_project_configGoogle::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceTenantProjectConfig

The identity to configure a tenant project. Corresponds to the JSON property tenantProjectConfig



391
392
393
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 391

def tenant_project_config
  @tenant_project_config
end

#tenant_project_idString

Output only. The tenant project ID that has been created. Corresponds to the JSON property tenantProjectId

Returns:

  • (String)


396
397
398
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 396

def tenant_project_id
  @tenant_project_id
end

#tenant_project_numberFixnum

Output only. The tenant project number that has been created. Corresponds to the JSON property tenantProjectNumber

Returns:

  • (Fixnum)


401
402
403
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 401

def tenant_project_number
  @tenant_project_number
end

#tenant_service_accountsArray<Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceTenantServiceAccountIdentity>

The service account identities (or enabled API service's P4SA) that are expclicitly created under the tenant project (before JIT provisioning during enabled API services). Corresponds to the JSON property tenantServiceAccounts



408
409
410
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 408

def tenant_service_accounts
  @tenant_service_accounts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



415
416
417
418
419
420
421
422
423
424
425
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 415

def update!(**args)
  @cloud_sql_instances = args[:cloud_sql_instances] if args.key?(:cloud_sql_instances)
  @gcs_buckets = args[:gcs_buckets] if args.key?(:gcs_buckets)
  @iam_policy_bindings = args[:iam_policy_bindings] if args.key?(:iam_policy_bindings)
  @infra_spanner_configs = args[:infra_spanner_configs] if args.key?(:infra_spanner_configs)
  @tag = args[:tag] if args.key?(:tag)
  @tenant_project_config = args[:tenant_project_config] if args.key?(:tenant_project_config)
  @tenant_project_id = args[:tenant_project_id] if args.key?(:tenant_project_id)
  @tenant_project_number = args[:tenant_project_number] if args.key?(:tenant_project_number)
  @tenant_service_accounts = args[:tenant_service_accounts] if args.key?(:tenant_service_accounts)
end