Class: Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceTenantResource
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceTenantResource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
A collection of tenant resources.
Instance Attribute Summary collapse
-
#p4_service_accounts ⇒ Array<Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceServiceAccountIdentity>
A list of P4 service accounts (go/p4sa) to provision or deprovision.
-
#tenant_project_resources ⇒ Array<Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceTenantProjectResource>
A list of tenant projects and tenant resources to provision or deprovision.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiPlatformTenantresourceTenantResource
constructor
A new instance of CloudAiPlatformTenantresourceTenantResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiPlatformTenantresourceTenantResource
Returns a new instance of CloudAiPlatformTenantresourceTenantResource.
442 443 444 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#p4_service_accounts ⇒ Array<Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceServiceAccountIdentity>
A list of P4 service accounts (go/p4sa) to provision or deprovision.
Corresponds to the JSON property p4ServiceAccounts
435 436 437 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 435 def p4_service_accounts @p4_service_accounts end |
#tenant_project_resources ⇒ Array<Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceTenantProjectResource>
A list of tenant projects and tenant resources to provision or deprovision.
Corresponds to the JSON property tenantProjectResources
440 441 442 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 440 def tenant_project_resources @tenant_project_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
447 448 449 450 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 447 def update!(**args) @p4_service_accounts = args[:p4_service_accounts] if args.key?(:p4_service_accounts) @tenant_project_resources = args[:tenant_project_resources] if args.key?(:tenant_project_resources) end |