Class: Google::Apis::ContentwarehouseV1::ContentwarehouseService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::ContentwarehouseV1::ContentwarehouseService
- Defined in:
- lib/google/apis/contentwarehouse_v1/service.rb
Overview
Document AI Warehouse API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://contentwarehouse.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_document(parent, google_cloud_contentwarehouse_v1_create_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CreateDocumentResponse
Creates a document.
-
#create_project_location_document_document_link(parent, google_cloud_contentwarehouse_v1_create_document_link_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentLink
Create a link between a source document and a target document.
-
#create_project_location_document_schema(parent, google_cloud_contentwarehouse_v1_document_schema_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema
Creates a document schema.
-
#create_project_location_rule_set(parent, google_cloud_contentwarehouse_v1_rule_set_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet
Creates a ruleset.
-
#create_project_location_synonym_set(parent, google_cloud_contentwarehouse_v1_synonym_set_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet
Creates a SynonymSet for a single context.
-
#delete_project_location_document(name, google_cloud_contentwarehouse_v1_delete_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a document.
-
#delete_project_location_document_document_link(name, google_cloud_contentwarehouse_v1_delete_document_link_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Remove the link between the source and target documents.
-
#delete_project_location_document_reference_id(name, google_cloud_contentwarehouse_v1_delete_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a document.
-
#delete_project_location_document_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a document schema.
-
#delete_project_location_rule_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a ruleset.
-
#delete_project_location_synonym_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a SynonymSet for a given context.
-
#fetch_project_acl(resource, google_cloud_contentwarehouse_v1_fetch_acl_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclResponse
Gets the access control policy for a resource.
-
#fetch_project_location_document_acl(resource, google_cloud_contentwarehouse_v1_fetch_acl_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclResponse
Gets the access control policy for a resource.
-
#get_project_location_document(name, google_cloud_contentwarehouse_v1_get_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Gets a document.
-
#get_project_location_document_reference_id(name, google_cloud_contentwarehouse_v1_get_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Gets a document.
-
#get_project_location_document_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema
Gets a document schema.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_rule_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet
Gets a ruleset.
-
#get_project_location_status(location, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProjectStatus
Get the project status.
-
#get_project_location_synonym_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet
Gets a SynonymSet for a particular context.
-
#initialize ⇒ ContentwarehouseService
constructor
A new instance of ContentwarehouseService.
-
#initialize_project_location(location, google_cloud_contentwarehouse_v1_initialize_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation
Provisions resources for given tenant project.
-
#linked_project_location_document_sources(parent, google_cloud_contentwarehouse_v1_list_linked_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedSourcesResponse
Return all source document-links from the document.
-
#linked_project_location_document_targets(parent, google_cloud_contentwarehouse_v1_list_linked_targets_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedTargetsResponse
Return all target document-links from the document.
-
#list_project_location_document_schemas(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListDocumentSchemasResponse
Lists document schemas.
-
#list_project_location_rule_sets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListRuleSetsResponse
Lists rulesets.
-
#list_project_location_synonym_sets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListSynonymSetsResponse
Returns all SynonymSets (for all contexts) for the specified location.
-
#lock_project_location_document(name, google_cloud_contentwarehouse_v1_lock_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Lock the document so the document cannot be updated by other users.
-
#patch_project_location_document(name, google_cloud_contentwarehouse_v1_update_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse
Updates a document.
-
#patch_project_location_document_reference_id(name, google_cloud_contentwarehouse_v1_update_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse
Updates a document.
-
#patch_project_location_document_schema(name, google_cloud_contentwarehouse_v1_update_document_schema_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema
Updates a Document Schema.
-
#patch_project_location_rule_set(name, google_cloud_contentwarehouse_v1_update_rule_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet
Updates a ruleset.
-
#patch_project_location_synonym_set(name, google_cloud_contentwarehouse_v1_synonym_set_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet
Remove the existing SynonymSet for the context and replaces it with a new one.
-
#run_project_location_pipeline(name, google_cloud_contentwarehouse_v1_run_pipeline_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation
Run a predefined pipeline.
-
#search_project_location_documents(parent, google_cloud_contentwarehouse_v1_search_documents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsResponse
Searches for documents using provided SearchDocumentsRequest.
-
#set_project_acl(resource, google_cloud_contentwarehouse_v1_set_acl_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclResponse
Sets the access control policy for a resource.
-
#set_project_location_document_acl(resource, google_cloud_contentwarehouse_v1_set_acl_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclResponse
Sets the access control policy for a resource.
Constructor Details
#initialize ⇒ ContentwarehouseService
Returns a new instance of ContentwarehouseService.
47 48 49 50 51 52 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-contentwarehouse_v1', client_version: Google::Apis::ContentwarehouseV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_project_location_document(parent, google_cloud_contentwarehouse_v1_create_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CreateDocumentResponse
Creates a document.
428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 428 def create_project_location_document(parent, google_cloud_contentwarehouse_v1_create_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/documents', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CreateDocumentRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_create_document_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CreateDocumentResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CreateDocumentResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_document_document_link(parent, google_cloud_contentwarehouse_v1_create_document_link_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentLink
Create a link between a source document and a target document.
784 785 786 787 788 789 790 791 792 793 794 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 784 def create_project_location_document_document_link(parent, google_cloud_contentwarehouse_v1_create_document_link_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/documentLinks', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CreateDocumentLinkRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_create_document_link_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentLink::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentLink command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_document_schema(parent, google_cloud_contentwarehouse_v1_document_schema_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema
Creates a document schema.
251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 251 def create_project_location_document_schema(parent, google_cloud_contentwarehouse_v1_document_schema_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/documentSchemas', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema::Representation command.request_object = google_cloud_contentwarehouse_v1_document_schema_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_rule_set(parent, google_cloud_contentwarehouse_v1_rule_set_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet
Creates a ruleset.
990 991 992 993 994 995 996 997 998 999 1000 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 990 def create_project_location_rule_set(parent, google_cloud_contentwarehouse_v1_rule_set_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/ruleSets', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet::Representation command.request_object = google_cloud_contentwarehouse_v1_rule_set_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_synonym_set(parent, google_cloud_contentwarehouse_v1_synonym_set_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet
Creates a SynonymSet for a single context. Throws an ALREADY_EXISTS exception if a synonymset already exists for the context.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 1163 def create_project_location_synonym_set(parent, google_cloud_contentwarehouse_v1_synonym_set_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/synonymSets', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet::Representation command.request_object = google_cloud_contentwarehouse_v1_synonym_set_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_document(name, google_cloud_contentwarehouse_v1_delete_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a document. Returns NOT_FOUND if the document does not exist.
463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 463 def delete_project_location_document(name, google_cloud_contentwarehouse_v1_delete_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:delete', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_delete_document_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_document_document_link(name, google_cloud_contentwarehouse_v1_delete_document_link_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Remove the link between the source and target documents.
819 820 821 822 823 824 825 826 827 828 829 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 819 def delete_project_location_document_document_link(name, google_cloud_contentwarehouse_v1_delete_document_link_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:delete', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentLinkRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_delete_document_link_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_document_reference_id(name, google_cloud_contentwarehouse_v1_delete_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a document. Returns NOT_FOUND if the document does not exist.
854 855 856 857 858 859 860 861 862 863 864 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 854 def delete_project_location_document_reference_id(name, google_cloud_contentwarehouse_v1_delete_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:delete', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_delete_document_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_document_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a document schema. Returns NOT_FOUND if the document schema does not exist. Returns BAD_REQUEST if the document schema has documents depending on it.
285 286 287 288 289 290 291 292 293 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 285 def delete_project_location_document_schema(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_rule_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a ruleset. Returns NOT_FOUND if the document does not exist.
1023 1024 1025 1026 1027 1028 1029 1030 1031 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 1023 def delete_project_location_rule_set(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_synonym_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty
Deletes a SynonymSet for a given context. Throws a NOT_FOUND exception if the SynonymSet is not found.
1197 1198 1199 1200 1201 1202 1203 1204 1205 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 1197 def delete_project_location_synonym_set(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#fetch_project_acl(resource, google_cloud_contentwarehouse_v1_fetch_acl_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclResponse
Gets the access control policy for a resource. Returns NOT_FOUND error if the resource does not exist. Returns an empty policy if the resource exists but does not have a policy set.
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 81 def fetch_project_acl(resource, google_cloud_contentwarehouse_v1_fetch_acl_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:fetchAcl', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_fetch_acl_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#fetch_project_location_document_acl(resource, google_cloud_contentwarehouse_v1_fetch_acl_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclResponse
Gets the access control policy for a resource. Returns NOT_FOUND error if the resource does not exist. Returns an empty policy if the resource exists but does not have a policy set.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 502 def fetch_project_location_document_acl(resource, google_cloud_contentwarehouse_v1_fetch_acl_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:fetchAcl', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_fetch_acl_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_document(name, google_cloud_contentwarehouse_v1_get_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Gets a document. Returns NOT_FOUND if the document does not exist.
537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 537 def get_project_location_document(name, google_cloud_contentwarehouse_v1_get_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:get', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GetDocumentRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_get_document_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_document_reference_id(name, google_cloud_contentwarehouse_v1_get_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Gets a document. Returns NOT_FOUND if the document does not exist.
889 890 891 892 893 894 895 896 897 898 899 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 889 def get_project_location_document_reference_id(name, google_cloud_contentwarehouse_v1_get_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:get', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GetDocumentRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_get_document_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_document_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema
Gets a document schema. Returns NOT_FOUND if the document schema does not exist.
316 317 318 319 320 321 322 323 324 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 316 def get_project_location_document_schema(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
958 959 960 961 962 963 964 965 966 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 958 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_rule_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet
Gets a ruleset. Returns NOT_FOUND if the ruleset does not exist.
1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 1054 def get_project_location_rule_set(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_status(location, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProjectStatus
Get the project status.
151 152 153 154 155 156 157 158 159 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 151 def get_project_location_status(location, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+location}:getStatus', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProjectStatus::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProjectStatus command.params['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_synonym_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet
Gets a SynonymSet for a particular context. Throws a NOT_FOUND exception if the Synonymset does not exist
1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 1229 def get_project_location_synonym_set(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#initialize_project_location(location, google_cloud_contentwarehouse_v1_initialize_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation
Provisions resources for given tenant project. Returns a long running operation.
184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 184 def initialize_project_location(location, google_cloud_contentwarehouse_v1_initialize_project_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+location}:initialize', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1InitializeProjectRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_initialize_project_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation command.params['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#linked_project_location_document_sources(parent, google_cloud_contentwarehouse_v1_list_linked_sources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedSourcesResponse
Return all source document-links from the document.
572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 572 def linked_project_location_document_sources(parent, google_cloud_contentwarehouse_v1_list_linked_sources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/linkedSources', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedSourcesRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_list_linked_sources_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedSourcesResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedSourcesResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#linked_project_location_document_targets(parent, google_cloud_contentwarehouse_v1_list_linked_targets_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedTargetsResponse
Return all target document-links from the document.
607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 607 def linked_project_location_document_targets(parent, google_cloud_contentwarehouse_v1_list_linked_targets_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/linkedTargets', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedTargetsRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_list_linked_targets_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedTargetsResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedTargetsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_document_schemas(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListDocumentSchemasResponse
Lists document schemas.
356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 356 def list_project_location_document_schemas(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/documentSchemas', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListDocumentSchemasResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListDocumentSchemasResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_rule_sets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListRuleSetsResponse
Lists rulesets.
1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 1093 def list_project_location_rule_sets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/ruleSets', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListRuleSetsResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListRuleSetsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_synonym_sets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListSynonymSetsResponse
Returns all SynonymSets (for all contexts) for the specified location.
1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 1268 def list_project_location_synonym_sets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/synonymSets', ) command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListSynonymSetsResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListSynonymSetsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lock_project_location_document(name, google_cloud_contentwarehouse_v1_lock_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Lock the document so the document cannot be updated by other users.
641 642 643 644 645 646 647 648 649 650 651 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 641 def lock_project_location_document(name, google_cloud_contentwarehouse_v1_lock_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:lock', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1LockDocumentRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_lock_document_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_document(name, google_cloud_contentwarehouse_v1_update_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse
Updates a document. Returns INVALID_ARGUMENT if the name of the document is non-empty and does not equal the existing name.
677 678 679 680 681 682 683 684 685 686 687 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 677 def patch_project_location_document(name, google_cloud_contentwarehouse_v1_update_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_update_document_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_document_reference_id(name, google_cloud_contentwarehouse_v1_update_document_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse
Updates a document. Returns INVALID_ARGUMENT if the name of the document is non-empty and does not equal the existing name.
925 926 927 928 929 930 931 932 933 934 935 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 925 def patch_project_location_document_reference_id(name, google_cloud_contentwarehouse_v1_update_document_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_update_document_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_document_schema(name, google_cloud_contentwarehouse_v1_update_document_schema_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema
Updates a Document Schema. Returns INVALID_ARGUMENT if the name of the Document Schema is non-empty and does not equal the existing name. Supports only appending new properties, adding new ENUM possible values, and updating the EnumTypeOptions.validation_check_disabled flag for ENUM possible values. Updating existing properties will result into INVALID_ARGUMENT.
394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 394 def patch_project_location_document_schema(name, google_cloud_contentwarehouse_v1_update_document_schema_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentSchemaRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_update_document_schema_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_rule_set(name, google_cloud_contentwarehouse_v1_update_rule_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet
Updates a ruleset. Returns INVALID_ARGUMENT if the name of the ruleset is non- empty and does not equal the existing name.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 1128 def patch_project_location_rule_set(name, google_cloud_contentwarehouse_v1_update_rule_set_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateRuleSetRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_update_rule_set_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_synonym_set(name, google_cloud_contentwarehouse_v1_synonym_set_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet
Remove the existing SynonymSet for the context and replaces it with a new one. Throws a NOT_FOUND exception if the SynonymSet is not found.
1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 1303 def patch_project_location_synonym_set(name, google_cloud_contentwarehouse_v1_synonym_set_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet::Representation command.request_object = google_cloud_contentwarehouse_v1_synonym_set_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSet command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#run_project_location_pipeline(name, google_cloud_contentwarehouse_v1_run_pipeline_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation
Run a predefined pipeline.
218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 218 def run_project_location_pipeline(name, google_cloud_contentwarehouse_v1_run_pipeline_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:runPipeline', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_run_pipeline_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_location_documents(parent, google_cloud_contentwarehouse_v1_search_documents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsResponse
Searches for documents using provided SearchDocumentsRequest. This call only returns documents that the caller has permission to search against.
712 713 714 715 716 717 718 719 720 721 722 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 712 def search_project_location_documents(parent, google_cloud_contentwarehouse_v1_search_documents_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/documents:search', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_search_documents_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_acl(resource, google_cloud_contentwarehouse_v1_set_acl_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclResponse
Sets the access control policy for a resource. Replaces any existing policy.
118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 118 def set_project_acl(resource, google_cloud_contentwarehouse_v1_set_acl_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setAcl', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_set_acl_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_document_acl(resource, google_cloud_contentwarehouse_v1_set_acl_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclResponse
Sets the access control policy for a resource. Replaces any existing policy.
749 750 751 752 753 754 755 756 757 758 759 |
# File 'lib/google/apis/contentwarehouse_v1/service.rb', line 749 def set_project_location_document_acl(resource, google_cloud_contentwarehouse_v1_set_acl_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setAcl', ) command.request_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclRequest::Representation command.request_object = google_cloud_contentwarehouse_v1_set_acl_request_object command.response_representation = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclResponse::Representation command.response_class = Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |