Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CreateDocumentRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Request message for DocumentService.CreateDocument.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1CreateDocumentRequest

Returns a new instance of GoogleCloudContentwarehouseV1CreateDocumentRequest.



833
834
835
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_ai_document_optionGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CloudAiDocumentOption

Request Option for processing Cloud AI Document in CW Document. Corresponds to the JSON property cloudAiDocumentOption



783
784
785
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 783

def cloud_ai_document_option
  @cloud_ai_document_option
end

#create_maskString

Field mask for creating Document fields. If mask path is empty, it means all fields are masked. For the FieldMask definition, see https://developers. google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask. Corresponds to the JSON property createMask

Returns:

  • (String)


790
791
792
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 790

def create_mask
  @create_mask
end

#documentGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document

Defines the structure for content warehouse document proto. Corresponds to the JSON property document



795
796
797
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 795

def document
  @document
end

#policyGoogle::Apis::ContentwarehouseV1::GoogleIamV1Policy

An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources. A Policy is a collection of bindings. A binding binds one or more members, or principals, to a single role. Principals can be user accounts, service accounts, Google groups, and domains ( such as G Suite). A role is a named list of permissions; each role can be an IAM predefined role or a user-created custom role. For some types of Google Cloud resources, a binding can also specify a condition, which is a logical expression that allows access to a resource only if the expression evaluates to true. A condition can add constraints based on attributes of the request, the resource, or both. To learn which resources support conditions in their IAM policies, see the IAM documentation. JSON example: ` " bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [ "user:mike@example.com", "group:admins@example.com", "domain:google.com", " serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": " roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com" ], "condition": ` "title": "expirable access", "description": "Does not grant access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00: 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` YAML example: bindings: - members: - user:mike@example.com - group:admins@ example.com - domain:google.com - serviceAccount:my-project-id@appspot. gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.com role: roles/resourcemanager.organizationViewer condition: title: expirable access description: Does not grant access after Sep 2020 expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For a description of IAM and its features, see the IAM documentation. Corresponds to the JSON property policy



826
827
828
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 826

def policy
  @policy
end

#request_metadataGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata

Meta information is used to improve the performance of the service. Corresponds to the JSON property requestMetadata



831
832
833
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 831

def 
  @request_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



838
839
840
841
842
843
844
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 838

def update!(**args)
  @cloud_ai_document_option = args[:cloud_ai_document_option] if args.key?(:cloud_ai_document_option)
  @create_mask = args[:create_mask] if args.key?(:create_mask)
  @document = args[:document] if args.key?(:document)
  @policy = args[:policy] if args.key?(:policy)
  @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
end