Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentAction
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents the action responsible for deleting the document.
Instance Attribute Summary collapse
-
#enable_hard_delete ⇒ Boolean
(also: #enable_hard_delete?)
Boolean field to select between hard vs soft delete options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DeleteDocumentAction
constructor
A new instance of GoogleCloudContentwarehouseV1DeleteDocumentAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DeleteDocumentAction
Returns a new instance of GoogleCloudContentwarehouseV1DeleteDocumentAction.
990 991 992 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_hard_delete ⇒ Boolean Also known as: enable_hard_delete?
Boolean field to select between hard vs soft delete options. Set 'true' for '
hard delete' and 'false' for 'soft delete'.
Corresponds to the JSON property enableHardDelete
987 988 989 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 987 def enable_hard_delete @enable_hard_delete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
995 996 997 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 995 def update!(**args) @enable_hard_delete = args[:enable_hard_delete] if args.key?(:enable_hard_delete) end |