Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Request message for DocumentService.DeleteDocument.
Instance Attribute Summary collapse
-
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DeleteDocumentRequest
constructor
A new instance of GoogleCloudContentwarehouseV1DeleteDocumentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DeleteDocumentRequest
Returns a new instance of GoogleCloudContentwarehouseV1DeleteDocumentRequest.
1028 1029 1030 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
Corresponds to the JSON property requestMetadata
1026 1027 1028 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1026 def @request_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1033 1034 1035 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1033 def update!(**args) @request_metadata = args[:request_metadata] if args.key?(:request_metadata) end |