Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentLink

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

A document-link between source and target document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DocumentLink

Returns a new instance of GoogleCloudContentwarehouseV1DocumentLink.



1239
1240
1241
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the documentLink is created. Corresponds to the JSON property createTime

Returns:

  • (String)


1202
1203
1204
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1202

def create_time
  @create_time
end

#descriptionString

Description of this document-link. Corresponds to the JSON property description

Returns:

  • (String)


1207
1208
1209
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1207

def description
  @description
end

#nameString

Name of this document-link. It is required that the parent derived form the name to be consistent with the source document reference. Otherwise an exception will be thrown. Format: projects/project_number/locations/ location/documents/source_document_id/documentLinks/document_link_id. Corresponds to the JSON property name

Returns:

  • (String)


1215
1216
1217
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1215

def name
  @name
end

#source_document_referenceGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentReference

References to the documents. Corresponds to the JSON property sourceDocumentReference



1220
1221
1222
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1220

def source_document_reference
  @source_document_reference
end

#stateString

The state of the documentlink. If target node has been deleted, the link is marked as invalid. Removing a source node will result in removal of all associated links. Corresponds to the JSON property state

Returns:

  • (String)


1227
1228
1229
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1227

def state
  @state
end

#target_document_referenceGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentReference

References to the documents. Corresponds to the JSON property targetDocumentReference



1232
1233
1234
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1232

def target_document_reference
  @target_document_reference
end

#update_timeString

Output only. The time when the documentLink is last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1237
1238
1239
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1237

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1244
1245
1246
1247
1248
1249
1250
1251
1252
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1244

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @source_document_reference = args[:source_document_reference] if args.key?(:source_document_reference)
  @state = args[:state] if args.key?(:state)
  @target_document_reference = args[:target_document_reference] if args.key?(:target_document_reference)
  @update_time = args[:update_time] if args.key?(:update_time)
end