Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentReference

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

References to the documents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DocumentReference

Returns a new instance of GoogleCloudContentwarehouseV1DocumentReference.



1453
1454
1455
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the document is created. Corresponds to the JSON property createTime

Returns:

  • (String)


1405
1406
1407
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1405

def create_time
  @create_time
end

#delete_timeString

Output only. The time when the document is deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1410

def delete_time
  @delete_time
end

#display_nameString

display_name of the referenced document; this name does not need to be consistent to the display_name in the Document proto, depending on the ACL constraint. Corresponds to the JSON property displayName

Returns:

  • (String)


1417
1418
1419
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1417

def display_name
  @display_name
end

#document_is_folderBoolean Also known as: document_is_folder?

The document type of the document being referenced. Corresponds to the JSON property documentIsFolder

Returns:

  • (Boolean)


1422
1423
1424
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1422

def document_is_folder
  @document_is_folder
end

Document is a folder with legal hold. Corresponds to the JSON property documentIsLegalHoldFolder

Returns:

  • (Boolean)


1428
1429
1430
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1428

def document_is_legal_hold_folder
  @document_is_legal_hold_folder
end

#document_is_retention_folderBoolean Also known as: document_is_retention_folder?

Document is a folder with retention policy. Corresponds to the JSON property documentIsRetentionFolder

Returns:

  • (Boolean)


1434
1435
1436
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1434

def document_is_retention_folder
  @document_is_retention_folder
end

#document_nameString

Required. Name of the referenced document. Corresponds to the JSON property documentName

Returns:

  • (String)


1440
1441
1442
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1440

def document_name
  @document_name
end

#snippetString

Stores the subset of the referenced document's content. This is useful to allow user peek the information of the referenced document. Corresponds to the JSON property snippet

Returns:

  • (String)


1446
1447
1448
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1446

def snippet
  @snippet
end

#update_timeString

Output only. The time when the document is last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1451
1452
1453
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1451

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1458

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @document_is_folder = args[:document_is_folder] if args.key?(:document_is_folder)
  @document_is_legal_hold_folder = args[:document_is_legal_hold_folder] if args.key?(:document_is_legal_hold_folder)
  @document_is_retention_folder = args[:document_is_retention_folder] if args.key?(:document_is_retention_folder)
  @document_name = args[:document_name] if args.key?(:document_name)
  @snippet = args[:snippet] if args.key?(:snippet)
  @update_time = args[:update_time] if args.key?(:update_time)
end