Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

A document schema used to define document structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DocumentSchema

Returns a new instance of GoogleCloudContentwarehouseV1DocumentSchema.



1514
1515
1516
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the document schema is created. Corresponds to the JSON property createTime

Returns:

  • (String)


1478
1479
1480
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1478

def create_time
  @create_time
end

#descriptionString

Schema description. Corresponds to the JSON property description

Returns:

  • (String)


1483
1484
1485
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1483

def description
  @description
end

#display_nameString

Required. Name of the schema given by the user. Must be unique per project. Corresponds to the JSON property displayName

Returns:

  • (String)


1488
1489
1490
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1488

def display_name
  @display_name
end

#document_is_folderBoolean Also known as: document_is_folder?

Document Type, true refers the document is a folder, otherwise it is a typical document. Corresponds to the JSON property documentIsFolder

Returns:

  • (Boolean)


1494
1495
1496
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1494

def document_is_folder
  @document_is_folder
end

#nameString

The resource name of the document schema. Format: projects/project_number/ locations/location/documentSchemas/document_schema_id. The name is ignored when creating a document schema. Corresponds to the JSON property name

Returns:

  • (String)


1502
1503
1504
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1502

def name
  @name
end

#property_definitionsArray<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyDefinition>

Document details. Corresponds to the JSON property propertyDefinitions



1507
1508
1509
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1507

def property_definitions
  @property_definitions
end

#update_timeString

Output only. The time when the document schema is last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1512
1513
1514
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1512

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1519

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @document_is_folder = args[:document_is_folder] if args.key?(:document_is_folder)
  @name = args[:name] if args.key?(:name)
  @property_definitions = args[:property_definitions] if args.key?(:property_definitions)
  @update_time = args[:update_time] if args.key?(:update_time)
end