Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1EnumTypeOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Configurations for an enum/categorical property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1EnumTypeOptions

Returns a new instance of GoogleCloudContentwarehouseV1EnumTypeOptions.



1565
1566
1567
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#possible_valuesArray<String>

Required. List of possible enum values. Corresponds to the JSON property possibleValues

Returns:

  • (Array<String>)


1556
1557
1558
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1556

def possible_values
  @possible_values
end

#validation_check_disabledBoolean Also known as: validation_check_disabled?

Make sure the Enum property value provided in the document is in the possile value list during document creation. The validation check runs by default. Corresponds to the JSON property validationCheckDisabled

Returns:

  • (Boolean)


1562
1563
1564
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1562

def validation_check_disabled
  @validation_check_disabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1570
1571
1572
1573
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1570

def update!(**args)
  @possible_values = args[:possible_values] if args.key?(:possible_values)
  @validation_check_disabled = args[:validation_check_disabled] if args.key?(:validation_check_disabled)
end