Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FetchAclRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Request message for DocumentService.FetchAcl

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1FetchAclRequest

Returns a new instance of GoogleCloudContentwarehouseV1FetchAclRequest.



1656
1657
1658
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#project_ownerBoolean Also known as: project_owner?

For Get Project ACL only. Authorization check for end user will be ignored when project_owner=true. Corresponds to the JSON property projectOwner

Returns:

  • (Boolean)


1648
1649
1650
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1648

def project_owner
  @project_owner
end

#request_metadataGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata

Meta information is used to improve the performance of the service. Corresponds to the JSON property requestMetadata



1654
1655
1656
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1654

def 
  @request_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1661
1662
1663
1664
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1661

def update!(**args)
  @project_owner = args[:project_owner] if args.key?(:project_owner)
  @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
end