Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GcsIngestPipeline

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The configuration of the Cloud Storage Ingestion pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1GcsIngestPipeline

Returns a new instance of GoogleCloudContentwarehouseV1GcsIngestPipeline.



1805
1806
1807
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#input_pathString

The input Cloud Storage folder. All files under this folder will be imported to Document Warehouse. Format: gs:///. Corresponds to the JSON property inputPath

Returns:

  • (String)


1777
1778
1779
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1777

def input_path
  @input_path
end

#pipeline_configGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1IngestPipelineConfig

The ingestion pipeline config. Corresponds to the JSON property pipelineConfig



1782
1783
1784
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1782

def pipeline_config
  @pipeline_config
end

#processor_typeString

The Doc AI processor type name. Only used when the format of ingested files is Doc AI Document proto format. Corresponds to the JSON property processorType

Returns:

  • (String)


1788
1789
1790
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1788

def processor_type
  @processor_type
end

#schema_nameString

The Document Warehouse schema resource name. All documents processed by this pipeline will use this schema. Format: projects/project_number/locations/ location/documentSchemas/document_schema_id. Corresponds to the JSON property schemaName

Returns:

  • (String)


1795
1796
1797
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1795

def schema_name
  @schema_name
end

#skip_ingested_documentsBoolean Also known as: skip_ingested_documents?

The flag whether to skip ingested documents. If it is set to true, documents in Cloud Storage contains key "status" with value "status=ingested" in custom metadata will be skipped to ingest. Corresponds to the JSON property skipIngestedDocuments

Returns:

  • (Boolean)


1802
1803
1804
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1802

def skip_ingested_documents
  @skip_ingested_documents
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1810
1811
1812
1813
1814
1815
1816
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1810

def update!(**args)
  @input_path = args[:input_path] if args.key?(:input_path)
  @pipeline_config = args[:pipeline_config] if args.key?(:pipeline_config)
  @processor_type = args[:processor_type] if args.key?(:processor_type)
  @schema_name = args[:schema_name] if args.key?(:schema_name)
  @skip_ingested_documents = args[:skip_ingested_documents] if args.key?(:skip_ingested_documents)
end