Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GcsIngestWithDocAiProcessorsPipeline

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The configuration of the Cloud Storage Ingestion with DocAI Processors pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1GcsIngestWithDocAiProcessorsPipeline

Returns a new instance of GoogleCloudContentwarehouseV1GcsIngestWithDocAiProcessorsPipeline.



1861
1862
1863
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1861

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#extract_processor_infosArray<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProcessorInfo>

The extract processors information. One matched extract processor will be used to process documents based on the classify processor result. If no classify processor is specified, the first extract processor will be used. Corresponds to the JSON property extractProcessorInfos



1829
1830
1831
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1829

def extract_processor_infos
  @extract_processor_infos
end

#input_pathString

The input Cloud Storage folder. All files under this folder will be imported to Document Warehouse. Format: gs:///. Corresponds to the JSON property inputPath

Returns:

  • (String)


1835
1836
1837
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1835

def input_path
  @input_path
end

#pipeline_configGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1IngestPipelineConfig

The ingestion pipeline config. Corresponds to the JSON property pipelineConfig



1840
1841
1842
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1840

def pipeline_config
  @pipeline_config
end

#processor_results_folder_pathString

The Cloud Storage folder path used to store the raw results from processors. Format: gs:///. Corresponds to the JSON property processorResultsFolderPath

Returns:

  • (String)


1846
1847
1848
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1846

def processor_results_folder_path
  @processor_results_folder_path
end

#skip_ingested_documentsBoolean Also known as: skip_ingested_documents?

The flag whether to skip ingested documents. If it is set to true, documents in Cloud Storage contains key "status" with value "status=ingested" in custom metadata will be skipped to ingest. Corresponds to the JSON property skipIngestedDocuments

Returns:

  • (Boolean)


1853
1854
1855
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1853

def skip_ingested_documents
  @skip_ingested_documents
end

#split_classify_processor_infoGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProcessorInfo

The DocAI processor information. Corresponds to the JSON property splitClassifyProcessorInfo



1859
1860
1861
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1859

def split_classify_processor_info
  @split_classify_processor_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1866
1867
1868
1869
1870
1871
1872
1873
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1866

def update!(**args)
  @extract_processor_infos = args[:extract_processor_infos] if args.key?(:extract_processor_infos)
  @input_path = args[:input_path] if args.key?(:input_path)
  @pipeline_config = args[:pipeline_config] if args.key?(:pipeline_config)
  @processor_results_folder_path = args[:processor_results_folder_path] if args.key?(:processor_results_folder_path)
  @skip_ingested_documents = args[:skip_ingested_documents] if args.key?(:skip_ingested_documents)
  @split_classify_processor_info = args[:split_classify_processor_info] if args.key?(:split_classify_processor_info)
end