Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GetDocumentRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GetDocumentRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Request message for DocumentService.GetDocument.
Instance Attribute Summary collapse
-
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1GetDocumentRequest
constructor
A new instance of GoogleCloudContentwarehouseV1GetDocumentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1GetDocumentRequest
Returns a new instance of GoogleCloudContentwarehouseV1GetDocumentRequest.
1885 1886 1887 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
Corresponds to the JSON property requestMetadata
1883 1884 1885 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1883 def @request_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1890 1891 1892 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1890 def update!(**args) @request_metadata = args[:request_metadata] if args.key?(:request_metadata) end |