Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProcessWithDocAiPipeline

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The configuration of processing documents in Document Warehouse with DocAi processors pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1ProcessWithDocAiPipeline

Returns a new instance of GoogleCloudContentwarehouseV1ProcessWithDocAiPipeline.



2514
2515
2516
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentsArray<String>

The list of all the resource names of the documents to be processed. Format: projects/project_number/locations/location/documents/document_id. Corresponds to the JSON property documents

Returns:

  • (Array<String>)


2495
2496
2497
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2495

def documents
  @documents
end

#export_folder_pathString

The Cloud Storage folder path used to store the exported documents before being sent to CDW. Format: gs:///. Corresponds to the JSON property exportFolderPath

Returns:

  • (String)


2501
2502
2503
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2501

def export_folder_path
  @export_folder_path
end

#processor_infoGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProcessorInfo

The DocAI processor information. Corresponds to the JSON property processorInfo



2506
2507
2508
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2506

def processor_info
  @processor_info
end

#processor_results_folder_pathString

The Cloud Storage folder path used to store the raw results from processors. Format: gs:///. Corresponds to the JSON property processorResultsFolderPath

Returns:

  • (String)


2512
2513
2514
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2512

def processor_results_folder_path
  @processor_results_folder_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2519
2520
2521
2522
2523
2524
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2519

def update!(**args)
  @documents = args[:documents] if args.key?(:documents)
  @export_folder_path = args[:export_folder_path] if args.key?(:export_folder_path)
  @processor_info = args[:processor_info] if args.key?(:processor_info)
  @processor_results_folder_path = args[:processor_results_folder_path] if args.key?(:processor_results_folder_path)
end