Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProcessorInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

The DocAI processor information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1ProcessorInfo

Returns a new instance of GoogleCloudContentwarehouseV1ProcessorInfo.



2550
2551
2552
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_typeString

The processor will process the documents with this document type. Corresponds to the JSON property documentType

Returns:

  • (String)


2534
2535
2536
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2534

def document_type
  @document_type
end

#processor_nameString

The processor resource name. Format is projects/project/locations/location /processors/processor, or `projects/`project`/locations/`location`/ processors/`processor`/processorVersions/`processorVersion Corresponds to the JSON property processorName

Returns:

  • (String)


2541
2542
2543
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2541

def processor_name
  @processor_name
end

#schema_nameString

The Document schema resource name. All documents processed by this processor will use this schema. Format: projects/project_number/locations/location/ documentSchemas/document_schema_id. Corresponds to the JSON property schemaName

Returns:

  • (String)


2548
2549
2550
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2548

def schema_name
  @schema_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2555
2556
2557
2558
2559
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2555

def update!(**args)
  @document_type = args[:document_type] if args.key?(:document_type)
  @processor_name = args[:processor_name] if args.key?(:processor_name)
  @schema_name = args[:schema_name] if args.key?(:schema_name)
end