Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PublishAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Represents the action responsible for publishing messages to a Pub/Sub topic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1PublishAction

Returns a new instance of GoogleCloudContentwarehouseV1PublishAction.



2933
2934
2935
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messagesArray<String>

Messages to be published. Corresponds to the JSON property messages

Returns:

  • (Array<String>)


2926
2927
2928
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2926

def messages
  @messages
end

#topic_idString

The topic id in the Pub/Sub service for which messages will be published to. Corresponds to the JSON property topicId

Returns:

  • (String)


2931
2932
2933
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2931

def topic_id
  @topic_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2938
2939
2940
2941
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2938

def update!(**args)
  @messages = args[:messages] if args.key?(:messages)
  @topic_id = args[:topic_id] if args.key?(:topic_id)
end