Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RemoveFromFolderAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Represents the action responsible for remove a document from a specific folder.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RemoveFromFolderAction

Returns a new instance of GoogleCloudContentwarehouseV1RemoveFromFolderAction.



3012
3013
3014
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

Condition of the action to be executed. Corresponds to the JSON property condition

Returns:

  • (String)


3004
3005
3006
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3004

def condition
  @condition
end

#folderString

Name of the folder under which new document is to be added. Format: projects/ project_number/locations/location/documents/document_id. Corresponds to the JSON property folder

Returns:

  • (String)


3010
3011
3012
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3010

def folder
  @folder
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3017
3018
3019
3020
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3017

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @folder = args[:folder] if args.key?(:folder)
end