Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleActionsPair
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleActionsPair
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents a rule and outputs of associated actions.
Instance Attribute Summary collapse
-
#action_outputs ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ActionOutput>
Outputs of executing the actions associated with the above rule.
-
#rule ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule
Represents the rule for a content warehouse trigger.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RuleActionsPair
constructor
A new instance of GoogleCloudContentwarehouseV1RuleActionsPair.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RuleActionsPair
Returns a new instance of GoogleCloudContentwarehouseV1RuleActionsPair.
3121 3122 3123 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_outputs ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ActionOutput>
Outputs of executing the actions associated with the above rule.
Corresponds to the JSON property actionOutputs
3114 3115 3116 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3114 def action_outputs @action_outputs end |
#rule ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule
Represents the rule for a content warehouse trigger.
Corresponds to the JSON property rule
3119 3120 3121 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3119 def rule @rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3126 3127 3128 3129 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3126 def update!(**args) @action_outputs = args[:action_outputs] if args.key?(:action_outputs) @rule = args[:rule] if args.key?(:rule) end |