Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEvaluatorOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Represents the output of the Rule Evaluator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RuleEvaluatorOutput

Returns a new instance of GoogleCloudContentwarehouseV1RuleEvaluatorOutput.



3182
3183
3184
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#invalid_rulesArray<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1InvalidRule>

A subset of triggered rules that failed the validation check(s) after parsing. Corresponds to the JSON property invalidRules



3170
3171
3172
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3170

def invalid_rules
  @invalid_rules
end

#matched_rulesArray<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule>

A subset of triggered rules that are evaluated true for a given request. Corresponds to the JSON property matchedRules



3175
3176
3177
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3175

def matched_rules
  @matched_rules
end

#triggered_rulesArray<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule>

List of rules fetched from database for the given request trigger type. Corresponds to the JSON property triggeredRules



3180
3181
3182
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3180

def triggered_rules
  @triggered_rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3187
3188
3189
3190
3191
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3187

def update!(**args)
  @invalid_rules = args[:invalid_rules] if args.key?(:invalid_rules)
  @matched_rules = args[:matched_rules] if args.key?(:matched_rules)
  @triggered_rules = args[:triggered_rules] if args.key?(:triggered_rules)
end