Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Represents a set of rules from a single customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RuleSet

Returns a new instance of GoogleCloudContentwarehouseV1RuleSet.



3220
3221
3222
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Short description of the rule-set. Corresponds to the JSON property description

Returns:

  • (String)


3201
3202
3203
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3201

def description
  @description
end

#nameString

The resource name of the rule set. Managed internally. Format: projects/ project_number/locations/location/ruleSet/rule_set_id. The name is ignored when creating a rule set. Corresponds to the JSON property name

Returns:

  • (String)


3208
3209
3210
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3208

def name
  @name
end

#rulesArray<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Rule>

List of rules given by the customer. Corresponds to the JSON property rules



3213
3214
3215
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3213

def rules
  @rules
end

#sourceString

Source of the rules i.e., customer name. Corresponds to the JSON property source

Returns:

  • (String)


3218
3219
3220
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3218

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3225
3226
3227
3228
3229
3230
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3225

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @source = args[:source] if args.key?(:source)
end