Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Metadata message of RunPipeline method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RunPipelineMetadata

Returns a new instance of GoogleCloudContentwarehouseV1RunPipelineMetadata.



3272
3273
3274
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_to_cdw_pipeline_metadataGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataExportToCdwPipelineMetadata

The metadata message for Export-to-CDW pipeline. Corresponds to the JSON property exportToCdwPipelineMetadata



3240
3241
3242
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3240

def 
  @export_to_cdw_pipeline_metadata
end

#failed_file_countFixnum

Number of files that have failed at some point in the pipeline. Corresponds to the JSON property failedFileCount

Returns:

  • (Fixnum)


3245
3246
3247
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3245

def failed_file_count
  @failed_file_count
end

#gcs_ingest_pipeline_metadataGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataGcsIngestPipelineMetadata

The metadata message for GcsIngest pipeline. Corresponds to the JSON property gcsIngestPipelineMetadata



3250
3251
3252
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3250

def 
  @gcs_ingest_pipeline_metadata
end

#individual_document_statusesArray<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataIndividualDocumentStatus>

The list of response details of each document. Corresponds to the JSON property individualDocumentStatuses



3255
3256
3257
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3255

def individual_document_statuses
  @individual_document_statuses
end

#process_with_doc_ai_pipeline_metadataGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataProcessWithDocAiPipelineMetadata

The metadata message for Process-with-DocAi pipeline. Corresponds to the JSON property processWithDocAiPipelineMetadata



3260
3261
3262
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3260

def 
  @process_with_doc_ai_pipeline_metadata
end

#total_file_countFixnum

Number of files that were processed by the pipeline. Corresponds to the JSON property totalFileCount

Returns:

  • (Fixnum)


3265
3266
3267
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3265

def total_file_count
  @total_file_count
end

#user_infoGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UserInfo

The user information. Corresponds to the JSON property userInfo



3270
3271
3272
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3270

def 
  @user_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3277
3278
3279
3280
3281
3282
3283
3284
3285
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3277

def update!(**args)
  @export_to_cdw_pipeline_metadata = args[:export_to_cdw_pipeline_metadata] if args.key?(:export_to_cdw_pipeline_metadata)
  @failed_file_count = args[:failed_file_count] if args.key?(:failed_file_count)
  @gcs_ingest_pipeline_metadata = args[:gcs_ingest_pipeline_metadata] if args.key?(:gcs_ingest_pipeline_metadata)
  @individual_document_statuses = args[:individual_document_statuses] if args.key?(:individual_document_statuses)
  @process_with_doc_ai_pipeline_metadata = args[:process_with_doc_ai_pipeline_metadata] if args.key?(:process_with_doc_ai_pipeline_metadata)
  @total_file_count = args[:total_file_count] if args.key?(:total_file_count)
  @user_info = args[:user_info] if args.key?(:user_info)
end