Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataExportToCdwPipelineMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataExportToCdwPipelineMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
The metadata message for Export-to-CDW pipeline.
Instance Attribute Summary collapse
-
#doc_ai_dataset ⇒ String
The output CDW dataset resource name.
-
#documents ⇒ Array<String>
The input list of all the resource names of the documents to be exported.
-
#output_path ⇒ String
The output Cloud Storage folder in this pipeline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RunPipelineMetadataExportToCdwPipelineMetadata
constructor
A new instance of GoogleCloudContentwarehouseV1RunPipelineMetadataExportToCdwPipelineMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RunPipelineMetadataExportToCdwPipelineMetadata
Returns a new instance of GoogleCloudContentwarehouseV1RunPipelineMetadataExportToCdwPipelineMetadata.
3307 3308 3309 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#doc_ai_dataset ⇒ String
The output CDW dataset resource name.
Corresponds to the JSON property docAiDataset
3295 3296 3297 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3295 def doc_ai_dataset @doc_ai_dataset end |
#documents ⇒ Array<String>
The input list of all the resource names of the documents to be exported.
Corresponds to the JSON property documents
3300 3301 3302 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3300 def documents @documents end |
#output_path ⇒ String
The output Cloud Storage folder in this pipeline.
Corresponds to the JSON property outputPath
3305 3306 3307 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3305 def output_path @output_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3312 3313 3314 3315 3316 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3312 def update!(**args) @doc_ai_dataset = args[:doc_ai_dataset] if args.key?(:doc_ai_dataset) @documents = args[:documents] if args.key?(:documents) @output_path = args[:output_path] if args.key?(:output_path) end |