Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataProcessWithDocAiPipelineMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataProcessWithDocAiPipelineMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
The metadata message for Process-with-DocAi pipeline.
Instance Attribute Summary collapse
-
#documents ⇒ Array<String>
The input list of all the resource names of the documents to be processed.
-
#processor_info ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProcessorInfo
The DocAI processor information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RunPipelineMetadataProcessWithDocAiPipelineMetadata
constructor
A new instance of GoogleCloudContentwarehouseV1RunPipelineMetadataProcessWithDocAiPipelineMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RunPipelineMetadataProcessWithDocAiPipelineMetadata
Returns a new instance of GoogleCloudContentwarehouseV1RunPipelineMetadataProcessWithDocAiPipelineMetadata.
3382 3383 3384 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#documents ⇒ Array<String>
The input list of all the resource names of the documents to be processed.
Corresponds to the JSON property documents
3375 3376 3377 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3375 def documents @documents end |
#processor_info ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProcessorInfo
The DocAI processor information.
Corresponds to the JSON property processorInfo
3380 3381 3382 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3380 def processor_info @processor_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3387 3388 3389 3390 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3387 def update!(**args) @documents = args[:documents] if args.key?(:documents) @processor_info = args[:processor_info] if args.key?(:processor_info) end |