Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SetAclRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Request message for DocumentService.SetAcl.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1SetAclRequest

Returns a new instance of GoogleCloudContentwarehouseV1SetAclRequest.



3698
3699
3700
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policyGoogle::Apis::ContentwarehouseV1::GoogleIamV1Policy

An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources. A Policy is a collection of bindings. A binding binds one or more members, or principals, to a single role. Principals can be user accounts, service accounts, Google groups, and domains ( such as G Suite). A role is a named list of permissions; each role can be an IAM predefined role or a user-created custom role. For some types of Google Cloud resources, a binding can also specify a condition, which is a logical expression that allows access to a resource only if the expression evaluates to true. A condition can add constraints based on attributes of the request, the resource, or both. To learn which resources support conditions in their IAM policies, see the IAM documentation. JSON example: ` " bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [ "user:mike@example.com", "group:admins@example.com", "domain:google.com", " serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": " roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com" ], "condition": ` "title": "expirable access", "description": "Does not grant access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00: 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` YAML example: bindings: - members: - user:mike@example.com - group:admins@ example.com - domain:google.com - serviceAccount:my-project-id@appspot. gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.com role: roles/resourcemanager.organizationViewer condition: title: expirable access description: Does not grant access after Sep 2020 expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For a description of IAM and its features, see the IAM documentation. Corresponds to the JSON property policy



3684
3685
3686
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3684

def policy
  @policy
end

#project_ownerBoolean Also known as: project_owner?

For Set Project ACL only. Authorization check for end user will be ignored when project_owner=true. Corresponds to the JSON property projectOwner

Returns:

  • (Boolean)


3690
3691
3692
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3690

def project_owner
  @project_owner
end

#request_metadataGoogle::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata

Meta information is used to improve the performance of the service. Corresponds to the JSON property requestMetadata



3696
3697
3698
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3696

def 
  @request_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3703
3704
3705
3706
3707
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3703

def update!(**args)
  @policy = args[:policy] if args.key?(:policy)
  @project_owner = args[:project_owner] if args.key?(:project_owner)
  @request_metadata = args[:request_metadata] if args.key?(:request_metadata)
end