Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimeFilter

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Filter on create timestamp or update timestamp of documents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudContentwarehouseV1TimeFilter

Returns a new instance of GoogleCloudContentwarehouseV1TimeFilter.



3868
3869
3870
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#time_fieldString

Specifies which time field to filter documents on. Defaults to TimeField. UPLOAD_TIME. Corresponds to the JSON property timeField

Returns:

  • (String)


3858
3859
3860
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3858

def time_field
  @time_field
end

#time_rangeGoogle::Apis::ContentwarehouseV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



3866
3867
3868
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3866

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3873
3874
3875
3876
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3873

def update!(**args)
  @time_field = args[:time_field] if args.key?(:time_field)
  @time_range = args[:time_range] if args.key?(:time_range)
end