Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampValue
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampValue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Timestamp value type.
Instance Attribute Summary collapse
-
#text_value ⇒ String
The string must represent a valid instant in UTC and is parsed using java.time.
-
#timestamp_value ⇒ String
Timestamp value Corresponds to the JSON property
timestampValue.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1TimestampValue
constructor
A new instance of GoogleCloudContentwarehouseV1TimestampValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1TimestampValue
Returns a new instance of GoogleCloudContentwarehouseV1TimestampValue.
3926 3927 3928 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#text_value ⇒ String
The string must represent a valid instant in UTC and is parsed using java.time.
format.DateTimeFormatter.ISO_INSTANT. e.g. "2013-09-29T18:46:19Z"
Corresponds to the JSON property textValue
3919 3920 3921 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3919 def text_value @text_value end |
#timestamp_value ⇒ String
Timestamp value
Corresponds to the JSON property timestampValue
3924 3925 3926 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3924 def @timestamp_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3931 3932 3933 3934 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3931 def update!(**args) @text_value = args[:text_value] if args.key?(:text_value) @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value) end |