Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Request message for DocumentService.UpdateDocument.
Instance Attribute Summary collapse
-
#cloud_ai_document_option ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CloudAiDocumentOption
Request Option for processing Cloud AI Document in CW Document.
-
#document ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Defines the structure for content warehouse document proto.
-
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
-
#update_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateOptions
Options for Update operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1UpdateDocumentRequest
constructor
A new instance of GoogleCloudContentwarehouseV1UpdateDocumentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1UpdateDocumentRequest
Returns a new instance of GoogleCloudContentwarehouseV1UpdateDocumentRequest.
3974 3975 3976 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_ai_document_option ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CloudAiDocumentOption
Request Option for processing Cloud AI Document in CW Document.
Corresponds to the JSON property cloudAiDocumentOption
3957 3958 3959 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3957 def cloud_ai_document_option @cloud_ai_document_option end |
#document ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Defines the structure for content warehouse document proto.
Corresponds to the JSON property document
3962 3963 3964 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3962 def document @document end |
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
Corresponds to the JSON property requestMetadata
3967 3968 3969 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3967 def @request_metadata end |
#update_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateOptions
Options for Update operations.
Corresponds to the JSON property updateOptions
3972 3973 3974 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3972 def @update_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3979 3980 3981 3982 3983 3984 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3979 def update!(**args) @cloud_ai_document_option = args[:cloud_ai_document_option] if args.key?(:cloud_ai_document_option) @document = args[:document] if args.key?(:document) @request_metadata = args[:request_metadata] if args.key?(:request_metadata) @update_options = args[:update_options] if args.key?(:update_options) end |