Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents the page footer associated with the chunk.
Instance Attribute Summary collapse
-
#page_span ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#text ⇒ String
Footer in text format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter
constructor
A new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter
Returns a new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter.
4531 4532 4533 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_span ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
4524 4525 4526 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4524 def page_span @page_span end |
#text ⇒ String
Footer in text format.
Corresponds to the JSON property text
4529 4530 4531 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4529 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4536 4537 4538 4539 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4536 def update!(**args) @page_span = args[:page_span] if args.key?(:page_span) @text = args[:text] if args.key?(:text) end |