Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Represents a block. A block could be one of the various types (text, table, list) supported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock

Returns a new instance of GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock.



4642
4643
4644
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#block_idString

ID of the block. Corresponds to the JSON property blockId

Returns:

  • (String)


4620
4621
4622
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4620

def block_id
  @block_id
end

#list_blockGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock

Represents a list type block. Corresponds to the JSON property listBlock



4625
4626
4627
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4625

def list_block
  @list_block
end

#page_spanGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan

Represents where the block starts and ends in the document. Corresponds to the JSON property pageSpan



4630
4631
4632
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4630

def page_span
  @page_span
end

#table_blockGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock

Represents a table type block. Corresponds to the JSON property tableBlock



4635
4636
4637
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4635

def table_block
  @table_block
end

#text_blockGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock

Represents a text type block. Corresponds to the JSON property textBlock



4640
4641
4642
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4640

def text_block
  @text_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4647
4648
4649
4650
4651
4652
4653
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4647

def update!(**args)
  @block_id = args[:block_id] if args.key?(:block_id)
  @list_block = args[:list_block] if args.key?(:list_block)
  @page_span = args[:page_span] if args.key?(:page_span)
  @table_block = args[:table_block] if args.key?(:table_block)
  @text_block = args[:text_block] if args.key?(:text_block)
end