Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

An entity that could be a phrase in the text or a property that belongs to the document. It is a known entity type, such as a person, an organization, or location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentEntity

Returns a new instance of GoogleCloudDocumentaiV1DocumentEntity.



4910
4911
4912
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

Optional. Confidence of detected Schema entity. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


4852
4853
4854
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4852

def confidence
  @confidence
end

#idString

Optional. Canonical id. This will be a unique value in the entity list for this document. Corresponds to the JSON property id

Returns:

  • (String)


4858
4859
4860
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4858

def id
  @id
end

#mention_idString

Optional. Deprecated. Use id field instead. Corresponds to the JSON property mentionId

Returns:

  • (String)


4863
4864
4865
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4863

def mention_id
  @mention_id
end

#mention_textString

Optional. Text value of the entity e.g. 1600 Amphitheatre Pkwy. Corresponds to the JSON property mentionText

Returns:

  • (String)


4868
4869
4870
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4868

def mention_text
  @mention_text
end

#normalized_valueGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntityNormalizedValue

Parsed and normalized entity value. Corresponds to the JSON property normalizedValue



4873
4874
4875
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4873

def normalized_value
  @normalized_value
end

#page_anchorGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageAnchor

Referencing the visual context of the entity in the Document.pages. Page anchors can be cross-page, consist of multiple bounding polygons and optionally reference specific layout element types. Corresponds to the JSON property pageAnchor



4880
4881
4882
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4880

def page_anchor
  @page_anchor
end

#propertiesArray<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntity>

Optional. Entities can be nested to form a hierarchical data structure representing the content in the document. Corresponds to the JSON property properties



4886
4887
4888
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4886

def properties
  @properties
end

#provenanceGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



4892
4893
4894
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4892

def provenance
  @provenance
end

#redactedBoolean Also known as: redacted?

Optional. Whether the entity will be redacted for de-identification purposes. Corresponds to the JSON property redacted

Returns:

  • (Boolean)


4897
4898
4899
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4897

def redacted
  @redacted
end

#text_anchorGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextAnchor

Text reference indexing into the Document.text. Corresponds to the JSON property textAnchor



4903
4904
4905
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4903

def text_anchor
  @text_anchor
end

#typeString

Required. Entity type from a schema e.g. Address. Corresponds to the JSON property type

Returns:

  • (String)


4908
4909
4910
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4908

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4915
4916
4917
4918
4919
4920
4921
4922
4923
4924
4925
4926
4927
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4915

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @id = args[:id] if args.key?(:id)
  @mention_id = args[:mention_id] if args.key?(:mention_id)
  @mention_text = args[:mention_text] if args.key?(:mention_text)
  @normalized_value = args[:normalized_value] if args.key?(:normalized_value)
  @page_anchor = args[:page_anchor] if args.key?(:page_anchor)
  @properties = args[:properties] if args.key?(:properties)
  @provenance = args[:provenance] if args.key?(:provenance)
  @redacted = args[:redacted] if args.key?(:redacted)
  @text_anchor = args[:text_anchor] if args.key?(:text_anchor)
  @type = args[:type] if args.key?(:type)
end