Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageAnchorPageRef

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Represents a weak reference to a page element within a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageAnchorPageRef

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageAnchorPageRef.



5235
5236
5237
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_polyGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1BoundingPoly

A bounding polygon for the detected image annotation. Corresponds to the JSON property boundingPoly



5210
5211
5212
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5210

def bounding_poly
  @bounding_poly
end

#confidenceFloat

Optional. Confidence of detected page element, if applicable. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


5215
5216
5217
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5215

def confidence
  @confidence
end

#layout_idString

Optional. Deprecated. Use PageRef.bounding_poly instead. Corresponds to the JSON property layoutId

Returns:

  • (String)


5220
5221
5222
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5220

def layout_id
  @layout_id
end

#layout_typeString

Optional. The type of the layout element that is being referenced if any. Corresponds to the JSON property layoutType

Returns:

  • (String)


5225
5226
5227
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5225

def layout_type
  @layout_type
end

#pageFixnum

Required. Index into the Document.pages element, for example using Document. pages to locate the related page element. This field is skipped when its value is the default 0. See https://developers.google.com/protocol-buffers/ docs/proto3#json. Corresponds to the JSON property page

Returns:

  • (Fixnum)


5233
5234
5235
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5233

def page
  @page
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5240
5241
5242
5243
5244
5245
5246
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5240

def update!(**args)
  @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly)
  @confidence = args[:confidence] if args.key?(:confidence)
  @layout_id = args[:layout_id] if args.key?(:layout_id)
  @layout_type = args[:layout_type] if args.key?(:layout_type)
  @page = args[:page] if args.key?(:page)
end