Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageBlock
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
A block has a set of lines (collected into paragraphs) that have a common line- spacing and orientation.
Instance Attribute Summary collapse
-
#detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
-
#layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
-
#provenance ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in different revisions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageBlock
constructor
A new instance of GoogleCloudDocumentaiV1DocumentPageBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageBlock
Returns a new instance of GoogleCloudDocumentaiV1DocumentPageBlock.
5270 5271 5272 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
Corresponds to the JSON property detectedLanguages
5257 5258 5259 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5257 def detected_languages @detected_languages end |
#layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property layout
5262 5263 5264 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5262 def layout @layout end |
#provenance ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in
different revisions.
Corresponds to the JSON property provenance
5268 5269 5270 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5268 def provenance @provenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5275 5276 5277 5278 5279 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5275 def update!(**args) @detected_languages = args[:detected_languages] if args.key?(:detected_languages) @layout = args[:layout] if args.key?(:layout) @provenance = args[:provenance] if args.key?(:provenance) end |