Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedBarcode
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedBarcode
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
A detected barcode.
Instance Attribute Summary collapse
-
#barcode ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1Barcode
Encodes the detailed information of a barcode.
-
#layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageDetectedBarcode
constructor
A new instance of GoogleCloudDocumentaiV1DocumentPageDetectedBarcode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageDetectedBarcode
Returns a new instance of GoogleCloudDocumentaiV1DocumentPageDetectedBarcode.
5296 5297 5298 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#barcode ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1Barcode
Encodes the detailed information of a barcode.
Corresponds to the JSON property barcode
5289 5290 5291 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5289 def @barcode end |
#layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property layout
5294 5295 5296 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5294 def layout @layout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5301 5302 5303 5304 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5301 def update!(**args) @barcode = args[:barcode] if args.key?(:barcode) @layout = args[:layout] if args.key?(:layout) end |