Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Visual element describing a layout unit on a page.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageLayout

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageLayout.



5551
5552
5553
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_polyGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1BoundingPoly

A bounding polygon for the detected image annotation. Corresponds to the JSON property boundingPoly



5532
5533
5534
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5532

def bounding_poly
  @bounding_poly
end

#confidenceFloat

Confidence of the current Layout within context of the object this layout is for. e.g. confidence can be for a single token, a table, a visual element, etc. depending on context. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


5539
5540
5541
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5539

def confidence
  @confidence
end

#orientationString

Detected orientation for the Layout. Corresponds to the JSON property orientation

Returns:

  • (String)


5544
5545
5546
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5544

def orientation
  @orientation
end

#text_anchorGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextAnchor

Text reference indexing into the Document.text. Corresponds to the JSON property textAnchor



5549
5550
5551
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5549

def text_anchor
  @text_anchor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5556
5557
5558
5559
5560
5561
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5556

def update!(**args)
  @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly)
  @confidence = args[:confidence] if args.key?(:confidence)
  @orientation = args[:orientation] if args.key?(:orientation)
  @text_anchor = args[:text_anchor] if args.key?(:text_anchor)
end