Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLine

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

A collection of tokens that a human would perceive as a line. Does not cross column boundaries, can be horizontal, vertical, etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageLine

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageLine.



5585
5586
5587
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detected_languagesArray<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



5572
5573
5574
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5572

def detected_languages
  @detected_languages
end

#layoutGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



5577
5578
5579
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5577

def layout
  @layout
end

#provenanceGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



5583
5584
5585
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5583

def provenance
  @provenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5590
5591
5592
5593
5594
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5590

def update!(**args)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
end