Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageSymbol
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageSymbol
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
A detected symbol.
Instance Attribute Summary collapse
-
#detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
-
#layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageSymbol
constructor
A new instance of GoogleCloudDocumentaiV1DocumentPageSymbol.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageSymbol
Returns a new instance of GoogleCloudDocumentaiV1DocumentPageSymbol.
5685 5686 5687 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
Corresponds to the JSON property detectedLanguages
5678 5679 5680 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5678 def detected_languages @detected_languages end |
#layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property layout
5683 5684 5685 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5683 def layout @layout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5690 5691 5692 5693 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5690 def update!(**args) @detected_languages = args[:detected_languages] if args.key?(:detected_languages) @layout = args[:layout] if args.key?(:layout) end |