Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

A table representation similar to HTML table structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageTable

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageTable.



5726
5727
5728
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#body_rowsArray<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTableTableRow>

Body rows of the table. Corresponds to the JSON property bodyRows



5703
5704
5705
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5703

def body_rows
  @body_rows
end

#detected_languagesArray<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



5708
5709
5710
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5708

def detected_languages
  @detected_languages
end

#header_rowsArray<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTableTableRow>

Header rows of the table. Corresponds to the JSON property headerRows



5713
5714
5715
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5713

def header_rows
  @header_rows
end

#layoutGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



5718
5719
5720
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5718

def layout
  @layout
end

#provenanceGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



5724
5725
5726
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5724

def provenance
  @provenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5731
5732
5733
5734
5735
5736
5737
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5731

def update!(**args)
  @body_rows = args[:body_rows] if args.key?(:body_rows)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @header_rows = args[:header_rows] if args.key?(:header_rows)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
end