Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageToken

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

A detected token.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageToken

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageToken.



5826
5827
5828
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detected_breakGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTokenDetectedBreak

Detected break at the end of a Token. Corresponds to the JSON property detectedBreak



5803
5804
5805
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5803

def detected_break
  @detected_break
end

#detected_languagesArray<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



5808
5809
5810
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5808

def detected_languages
  @detected_languages
end

#layoutGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



5813
5814
5815
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5813

def layout
  @layout
end

#provenanceGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



5819
5820
5821
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5819

def provenance
  @provenance
end

#style_infoGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageTokenStyleInfo

Font and other text style attributes. Corresponds to the JSON property styleInfo



5824
5825
5826
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5824

def style_info
  @style_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5831
5832
5833
5834
5835
5836
5837
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5831

def update!(**args)
  @detected_break = args[:detected_break] if args.key?(:detected_break)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
  @style_info = args[:style_info] if args.key?(:style_info)
end