Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentRevision

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Contains past or forward revisions of this document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentRevision

Returns a new instance of GoogleCloudDocumentaiV1DocumentRevision.



6207
6208
6209
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentString

If the change was made by a person specify the name or id of that person. Corresponds to the JSON property agent

Returns:

  • (String)


6168
6169
6170
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6168

def agent
  @agent
end

#create_timeString

The time that the revision was created, internally generated by doc proto storage at the time of create. Corresponds to the JSON property createTime

Returns:

  • (String)


6174
6175
6176
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6174

def create_time
  @create_time
end

#human_reviewGoogle::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentRevisionHumanReview

Human Review information of the document. Corresponds to the JSON property humanReview



6179
6180
6181
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6179

def human_review
  @human_review
end

#idString

Id of the revision, internally generated by doc proto storage. Unique within the context of the document. Corresponds to the JSON property id

Returns:

  • (String)


6185
6186
6187
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6185

def id
  @id
end

#parentArray<Fixnum>

The revisions that this revision is based on. This can include one or more parent (when documents are merged.) This field represents the index into the revisions field. Corresponds to the JSON property parent

Returns:

  • (Array<Fixnum>)


6192
6193
6194
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6192

def parent
  @parent
end

#parent_idsArray<String>

The revisions that this revision is based on. Must include all the ids that have anything to do with this revision - eg. there are provenance.parent. revision fields that index into this field. Corresponds to the JSON property parentIds

Returns:

  • (Array<String>)


6199
6200
6201
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6199

def parent_ids
  @parent_ids
end

#processorString

If the annotation was made by processor identify the processor by its resource name. Corresponds to the JSON property processor

Returns:

  • (String)


6205
6206
6207
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6205

def processor
  @processor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6212
6213
6214
6215
6216
6217
6218
6219
6220
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6212

def update!(**args)
  @agent = args[:agent] if args.key?(:agent)
  @create_time = args[:create_time] if args.key?(:create_time)
  @human_review = args[:human_review] if args.key?(:human_review)
  @id = args[:id] if args.key?(:id)
  @parent = args[:parent] if args.key?(:parent)
  @parent_ids = args[:parent_ids] if args.key?(:parent_ids)
  @processor = args[:processor] if args.key?(:processor)
end