Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentRevisionHumanReview

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

Human Review information of the document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentRevisionHumanReview

Returns a new instance of GoogleCloudDocumentaiV1DocumentRevisionHumanReview.



6238
6239
6240
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Human review state. e.g. requested, succeeded, rejected. Corresponds to the JSON property state

Returns:

  • (String)


6230
6231
6232
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6230

def state
  @state
end

#state_messageString

A message providing more details about the current state of processing. For example, the rejection reason when the state is rejected. Corresponds to the JSON property stateMessage

Returns:

  • (String)


6236
6237
6238
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6236

def state_message
  @state_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6243
6244
6245
6246
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6243

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
end