Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentShardInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb

Overview

For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentShardInfo

Returns a new instance of GoogleCloudDocumentaiV1DocumentShardInfo.



6270
6271
6272
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#shard_countFixnum

Total number of shards. Corresponds to the JSON property shardCount

Returns:

  • (Fixnum)


6257
6258
6259
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6257

def shard_count
  @shard_count
end

#shard_indexFixnum

The 0-based index of this shard. Corresponds to the JSON property shardIndex

Returns:

  • (Fixnum)


6262
6263
6264
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6262

def shard_index
  @shard_index
end

#text_offsetFixnum

The index of the first character in Document.text in the overall document global text. Corresponds to the JSON property textOffset

Returns:

  • (Fixnum)


6268
6269
6270
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6268

def text_offset
  @text_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6275
6276
6277
6278
6279
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6275

def update!(**args)
  @shard_count = args[:shard_count] if args.key?(:shard_count)
  @shard_index = args[:shard_index] if args.key?(:shard_index)
  @text_offset = args[:text_offset] if args.key?(:text_offset)
end