Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextChange
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextChange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
This message is used for text changes aka. OCR corrections.
Instance Attribute Summary collapse
-
#changed_text ⇒ String
The text that replaces the text identified in the
text_anchor. -
#provenance ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance>
The history of this annotation.
-
#text_anchor ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextAnchor
Text reference indexing into the Document.text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentTextChange
constructor
A new instance of GoogleCloudDocumentaiV1DocumentTextChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentTextChange
Returns a new instance of GoogleCloudDocumentaiV1DocumentTextChange.
6533 6534 6535 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#changed_text ⇒ String
The text that replaces the text identified in the text_anchor.
Corresponds to the JSON property changedText
6521 6522 6523 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6521 def changed_text @changed_text end |
#provenance ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance>
The history of this annotation.
Corresponds to the JSON property provenance
6526 6527 6528 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6526 def provenance @provenance end |
#text_anchor ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextAnchor
Text reference indexing into the Document.text.
Corresponds to the JSON property textAnchor
6531 6532 6533 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6531 def text_anchor @text_anchor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6538 6539 6540 6541 6542 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6538 def update!(**args) @changed_text = args[:changed_text] if args.key?(:changed_text) @provenance = args[:provenance] if args.key?(:provenance) @text_anchor = args[:text_anchor] if args.key?(:text_anchor) end |