Class: Google::Apis::ContentwarehouseV1::GoogleTypeInterval
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleTypeInterval
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#start_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeInterval
constructor
A new instance of GoogleTypeInterval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeInterval
Returns a new instance of GoogleTypeInterval.
7272 7273 7274 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 7272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. Exclusive end of the interval. If specified, a Timestamp matching
this interval will have to be before the end.
Corresponds to the JSON property endTime
7264 7265 7266 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 7264 def end_time @end_time end |
#start_time ⇒ String
Optional. Inclusive start of the interval. If specified, a Timestamp matching
this interval will have to be the same or after the start.
Corresponds to the JSON property startTime
7270 7271 7272 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 7270 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7277 7278 7279 7280 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 7277 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |