Class: Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceIamPolicyBinding
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::CloudAiPlatformTenantresourceIamPolicyBinding
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
The dynamic IAM bindings to be granted after tenant projects are created.
Instance Attribute Summary collapse
-
#members ⇒ Array<String>
Input/Output [Required].
-
#resource ⇒ String
Input/Output [Required].
-
#resource_type ⇒ String
Input/Output [Required].
-
#role ⇒ String
Input/Output [Required].
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiPlatformTenantresourceIamPolicyBinding
constructor
A new instance of CloudAiPlatformTenantresourceIamPolicyBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiPlatformTenantresourceIamPolicyBinding
Returns a new instance of CloudAiPlatformTenantresourceIamPolicyBinding.
169 170 171 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#members ⇒ Array<String>
Input/Output [Required]. The member service accounts with the roles above.
Note: placeholders are same as the resource above.
Corresponds to the JSON property members
148 149 150 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 148 def members @members end |
#resource ⇒ String
Input/Output [Required]. The resource name that will be accessed by members,
which also depends on resource_type. Note: placeholders are supported in
resource names. For example, $tpn will be used when the tenant project
number is not ready.
Corresponds to the JSON property resource
156 157 158 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 156 def resource @resource end |
#resource_type ⇒ String
Input/Output [Required]. Specifies the type of resource that will be accessed
by members.
Corresponds to the JSON property resourceType
162 163 164 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 162 def resource_type @resource_type end |
#role ⇒ String
Input/Output [Required]. The role for members below.
Corresponds to the JSON property role
167 168 169 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 167 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
174 175 176 177 178 179 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 174 def update!(**args) @members = args[:members] if args.key?(:members) @resource = args[:resource] if args.key?(:resource) @resource_type = args[:resource_type] if args.key?(:resource_type) @role = args[:role] if args.key?(:role) end |