Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Action
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Action
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents the action triggered by Rule Engine when the rule is true.
Instance Attribute Summary collapse
-
#access_control ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1AccessControlAction
Represents the action responsible for access control list management operations.
-
#action_id ⇒ String
ID of the action.
-
#add_to_folder ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1AddToFolderAction
Represents the action responsible for adding document under a folder.
-
#data_update ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataUpdateAction
Represents the action responsible for properties update operations.
-
#data_validation ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataValidationAction
Represents the action responsible for data validation operations.
-
#delete_document_action ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentAction
Represents the action responsible for deleting the document.
-
#publish_to_pub_sub ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PublishAction
Represents the action responsible for publishing messages to a Pub/Sub topic.
-
#remove_from_folder_action ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RemoveFromFolderAction
Represents the action responsible for remove a document from a specific folder.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1Action
constructor
A new instance of GoogleCloudContentwarehouseV1Action.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1Action
Returns a new instance of GoogleCloudContentwarehouseV1Action.
625 626 627 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_control ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1AccessControlAction
Represents the action responsible for access control list management
operations.
Corresponds to the JSON property accessControl
588 589 590 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 588 def access_control @access_control end |
#action_id ⇒ String
ID of the action. Managed internally.
Corresponds to the JSON property actionId
593 594 595 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 593 def action_id @action_id end |
#add_to_folder ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1AddToFolderAction
Represents the action responsible for adding document under a folder.
Corresponds to the JSON property addToFolder
598 599 600 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 598 def add_to_folder @add_to_folder end |
#data_update ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataUpdateAction
Represents the action responsible for properties update operations.
Corresponds to the JSON property dataUpdate
603 604 605 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 603 def data_update @data_update end |
#data_validation ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataValidationAction
Represents the action responsible for data validation operations.
Corresponds to the JSON property dataValidation
608 609 610 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 608 def data_validation @data_validation end |
#delete_document_action ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DeleteDocumentAction
Represents the action responsible for deleting the document.
Corresponds to the JSON property deleteDocumentAction
613 614 615 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 613 def delete_document_action @delete_document_action end |
#publish_to_pub_sub ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PublishAction
Represents the action responsible for publishing messages to a Pub/Sub topic.
Corresponds to the JSON property publishToPubSub
618 619 620 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 618 def publish_to_pub_sub @publish_to_pub_sub end |
#remove_from_folder_action ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RemoveFromFolderAction
Represents the action responsible for remove a document from a specific folder.
Corresponds to the JSON property removeFromFolderAction
623 624 625 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 623 def remove_from_folder_action @remove_from_folder_action end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
630 631 632 633 634 635 636 637 638 639 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 630 def update!(**args) @access_control = args[:access_control] if args.key?(:access_control) @action_id = args[:action_id] if args.key?(:action_id) @add_to_folder = args[:add_to_folder] if args.key?(:add_to_folder) @data_update = args[:data_update] if args.key?(:data_update) @data_validation = args[:data_validation] if args.key?(:data_validation) @delete_document_action = args[:delete_document_action] if args.key?(:delete_document_action) @publish_to_pub_sub = args[:publish_to_pub_sub] if args.key?(:publish_to_pub_sub) @remove_from_folder_action = args[:remove_from_folder_action] if args.key?(:remove_from_folder_action) end |