Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1AddToFolderAction
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1AddToFolderAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents the action responsible for adding document under a folder.
Instance Attribute Summary collapse
-
#folders ⇒ Array<String>
Names of the folder under which new document is to be added.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1AddToFolderAction
constructor
A new instance of GoogleCloudContentwarehouseV1AddToFolderAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1AddToFolderAction
Returns a new instance of GoogleCloudContentwarehouseV1AddToFolderAction.
702 703 704 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folders ⇒ Array<String>
Names of the folder under which new document is to be added. Format: projects/
project_number/locations/location/documents/document_id.
Corresponds to the JSON property folders
700 701 702 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 700 def folders @folders end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
707 708 709 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 707 def update!(**args) @folders = args[:folders] if args.key?(:folders) end |