Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CreateDocumentResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1CreateDocumentResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Response message for DocumentService.CreateDocument.
Instance Attribute Summary collapse
-
#document ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Defines the structure for content warehouse document proto.
-
#long_running_operations ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation>
post-processing LROs Corresponds to the JSON property
longRunningOperations. -
#metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata
Additional information returned to client, such as debugging information.
-
#rule_engine_output ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEngineOutput
Records the output of Rule Engine including rule evaluation and actions result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1CreateDocumentResponse
constructor
A new instance of GoogleCloudContentwarehouseV1CreateDocumentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1CreateDocumentResponse
Returns a new instance of GoogleCloudContentwarehouseV1CreateDocumentResponse.
871 872 873 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Defines the structure for content warehouse document proto.
Corresponds to the JSON property document
854 855 856 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 854 def document @document end |
#long_running_operations ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleLongrunningOperation>
post-processing LROs
Corresponds to the JSON property longRunningOperations
859 860 861 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 859 def long_running_operations @long_running_operations end |
#metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata
Additional information returned to client, such as debugging information.
Corresponds to the JSON property metadata
864 865 866 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 864 def @metadata end |
#rule_engine_output ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEngineOutput
Records the output of Rule Engine including rule evaluation and actions result.
Corresponds to the JSON property ruleEngineOutput
869 870 871 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 869 def rule_engine_output @rule_engine_output end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
876 877 878 879 880 881 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 876 def update!(**args) @document = args[:document] if args.key?(:document) @long_running_operations = args[:long_running_operations] if args.key?(:long_running_operations) @metadata = args[:metadata] if args.key?(:metadata) @rule_engine_output = args[:rule_engine_output] if args.key?(:rule_engine_output) end |