Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataUpdateAction
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataUpdateAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents the action responsible for properties update operations.
Instance Attribute Summary collapse
-
#entries ⇒ Hash<String,String>
Map of (K, V) -> (valid name of the field, new value of the field) E.g., ("age" , "60") entry triggers update of field age with a value of 60.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DataUpdateAction
constructor
A new instance of GoogleCloudContentwarehouseV1DataUpdateAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DataUpdateAction
Returns a new instance of GoogleCloudContentwarehouseV1DataUpdateAction.
916 917 918 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entries ⇒ Hash<String,String>
Map of (K, V) -> (valid name of the field, new value of the field) E.g., ("age"
, "60") entry triggers update of field age with a value of 60. If the field is
not present then new entry is added. During update action execution, value
strings will be casted to appropriate types.
Corresponds to the JSON property entries
914 915 916 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 914 def entries @entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
921 922 923 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 921 def update!(**args) @entries = args[:entries] if args.key?(:entries) end |