Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataValidationAction
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DataValidationAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents the action responsible for data validation operations.
Instance Attribute Summary collapse
-
#conditions ⇒ Hash<String,String>
Map of (K, V) -> (field, string condition to be evaluated on the field) E.g., ( "age", "age > 18 && age < 60") entry triggers validation of field age with the given condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DataValidationAction
constructor
A new instance of GoogleCloudContentwarehouseV1DataValidationAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DataValidationAction
Returns a new instance of GoogleCloudContentwarehouseV1DataValidationAction.
937 938 939 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Hash<String,String>
Map of (K, V) -> (field, string condition to be evaluated on the field) E.g., (
"age", "age > 18 && age < 60") entry triggers validation of field age with the
given condition. Map entries will be ANDed during validation.
Corresponds to the JSON property conditions
935 936 937 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 935 def conditions @conditions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
942 943 944 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 942 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) end |