Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DocumentSchema
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
A document schema used to define document structure.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Schema description.
-
#display_name ⇒ String
Required.
-
#document_is_folder ⇒ Boolean
(also: #document_is_folder?)
Document Type, true refers the document is a folder, otherwise it is a typical document.
-
#name ⇒ String
The resource name of the document schema.
-
#property_definitions ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyDefinition>
Document details.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DocumentSchema
constructor
A new instance of GoogleCloudContentwarehouseV1DocumentSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1DocumentSchema
Returns a new instance of GoogleCloudContentwarehouseV1DocumentSchema.
1514 1515 1516 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the document schema is created.
Corresponds to the JSON property createTime
1478 1479 1480 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1478 def create_time @create_time end |
#description ⇒ String
Schema description.
Corresponds to the JSON property description
1483 1484 1485 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1483 def description @description end |
#display_name ⇒ String
Required. Name of the schema given by the user. Must be unique per project.
Corresponds to the JSON property displayName
1488 1489 1490 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1488 def display_name @display_name end |
#document_is_folder ⇒ Boolean Also known as: document_is_folder?
Document Type, true refers the document is a folder, otherwise it is a typical
document.
Corresponds to the JSON property documentIsFolder
1494 1495 1496 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1494 def document_is_folder @document_is_folder end |
#name ⇒ String
The resource name of the document schema. Format: projects/project_number/
locations/location/documentSchemas/document_schema_id. The name is ignored
when creating a document schema.
Corresponds to the JSON property name
1502 1503 1504 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1502 def name @name end |
#property_definitions ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyDefinition>
Document details.
Corresponds to the JSON property propertyDefinitions
1507 1508 1509 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1507 def property_definitions @property_definitions end |
#update_time ⇒ String
Output only. The time when the document schema is last updated.
Corresponds to the JSON property updateTime
1512 1513 1514 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1512 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1519 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @document_is_folder = args[:document_is_folder] if args.key?(:document_is_folder) @name = args[:name] if args.key?(:name) @property_definitions = args[:property_definitions] if args.key?(:property_definitions) @update_time = args[:update_time] if args.key?(:update_time) end |