Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ExportToCdwPipeline
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ExportToCdwPipeline
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
The configuration of exporting documents from the Document Warehouse to CDW pipeline.
Instance Attribute Summary collapse
-
#doc_ai_dataset ⇒ String
Optional.
-
#documents ⇒ Array<String>
The list of all the resource names of the documents to be processed.
-
#export_folder_path ⇒ String
The Cloud Storage folder path used to store the exported documents before being sent to CDW.
-
#training_split_ratio ⇒ Float
Ratio of training dataset split.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1ExportToCdwPipeline
constructor
A new instance of GoogleCloudContentwarehouseV1ExportToCdwPipeline.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1ExportToCdwPipeline
Returns a new instance of GoogleCloudContentwarehouseV1ExportToCdwPipeline.
1627 1628 1629 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#doc_ai_dataset ⇒ String
Optional. The CDW dataset resource name. This field is optional. If not set,
the documents will be exported to Cloud Storage only. Format: projects/
project/locations/location/processors/processor/dataset
Corresponds to the JSON property docAiDataset
1606 1607 1608 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1606 def doc_ai_dataset @doc_ai_dataset end |
#documents ⇒ Array<String>
The list of all the resource names of the documents to be processed. Format:
projects/project_number/locations/location/documents/document_id.
Corresponds to the JSON property documents
1612 1613 1614 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1612 def documents @documents end |
#export_folder_path ⇒ String
The Cloud Storage folder path used to store the exported documents before
being sent to CDW. Format: gs:///.
Corresponds to the JSON property exportFolderPath
1618 1619 1620 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1618 def export_folder_path @export_folder_path end |
#training_split_ratio ⇒ Float
Ratio of training dataset split. When importing into Document AI Workbench,
documents will be automatically split into training and test split category
with the specified ratio. This field is required if doc_ai_dataset is set.
Corresponds to the JSON property trainingSplitRatio
1625 1626 1627 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1625 def training_split_ratio @training_split_ratio end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1632 1633 1634 1635 1636 1637 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1632 def update!(**args) @doc_ai_dataset = args[:doc_ai_dataset] if args.key?(:doc_ai_dataset) @documents = args[:documents] if args.key?(:documents) @export_folder_path = args[:export_folder_path] if args.key?(:export_folder_path) @training_split_ratio = args[:training_split_ratio] if args.key?(:training_split_ratio) end |