Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQuery
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQuery
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
The histogram request.
Instance Attribute Summary collapse
-
#filters ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter
Optional.
-
#histogram_query ⇒ String
An expression specifies a histogram request against matching documents for searches.
-
#require_precise_result_size ⇒ Boolean
(also: #require_precise_result_size?)
Controls if the histogram query requires the return of a precise count.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1HistogramQuery
constructor
A new instance of GoogleCloudContentwarehouseV1HistogramQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1HistogramQuery
Returns a new instance of GoogleCloudContentwarehouseV1HistogramQuery.
1921 1922 1923 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filters ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter
Optional. Filter the result of histogram query by the property names. It only
works with histogram query count('FilterableProperties'). It is an optional.
It will perform histogram on all the property names for all the document
schemas. Setting this field will have a better performance.
Corresponds to the JSON property filters
1905 1906 1907 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1905 def filters @filters end |
#histogram_query ⇒ String
An expression specifies a histogram request against matching documents for
searches. See SearchDocumentsRequest.histogram_queries for details about
syntax.
Corresponds to the JSON property histogramQuery
1912 1913 1914 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1912 def histogram_query @histogram_query end |
#require_precise_result_size ⇒ Boolean Also known as: require_precise_result_size?
Controls if the histogram query requires the return of a precise count. Enable
this flag may adversely impact performance. Defaults to true.
Corresponds to the JSON property requirePreciseResultSize
1918 1919 1920 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1918 def require_precise_result_size @require_precise_result_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1926 1927 1928 1929 1930 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1926 def update!(**args) @filters = args[:filters] if args.key?(:filters) @histogram_query = args[:histogram_query] if args.key?(:histogram_query) @require_precise_result_size = args[:require_precise_result_size] if args.key?(:require_precise_result_size) end |