Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Instance Attribute Summary collapse
-
#document_schemas ⇒ Array<String>
This filter specifies the exact document schema(s) Document.
-
#property_names ⇒ Array<String>
It is optional.
-
#y_axis ⇒ String
By default, the y_axis is HISTOGRAM_YAXIS_DOCUMENT if this field is not set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter
constructor
A new instance of GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter
Returns a new instance of GoogleCloudContentwarehouseV1HistogramQueryPropertyNameFilter.
1961 1962 1963 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_schemas ⇒ Array<String>
This filter specifies the exact document schema(s) Document.
document_schema_name to run histogram query against. It is optional. It will
perform histogram for property names for all the document schemas if it is not
set. At most 10 document schema names are allowed. Format: projects/
project_number/locations/location/documentSchemas/document_schema_id.
Corresponds to the JSON property documentSchemas
1944 1945 1946 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1944 def document_schemas @document_schemas end |
#property_names ⇒ Array<String>
It is optional. It will perform histogram for all the property names if it is
not set. The properties need to be defined with the is_filterable flag set to
true and the name of the property should be in the format: "schemaId.
propertyName". The property needs to be defined in the schema. Example: the
schema id is abc. Then the name of property for property MORTGAGE_TYPE will be
"abc.MORTGAGE_TYPE".
Corresponds to the JSON property propertyNames
1954 1955 1956 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1954 def property_names @property_names end |
#y_axis ⇒ String
By default, the y_axis is HISTOGRAM_YAXIS_DOCUMENT if this field is not set.
Corresponds to the JSON property yAxis
1959 1960 1961 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1959 def y_axis @y_axis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1966 1967 1968 1969 1970 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1966 def update!(**args) @document_schemas = args[:document_schemas] if args.key?(:document_schemas) @property_names = args[:property_names] if args.key?(:property_names) @y_axis = args[:y_axis] if args.key?(:y_axis) end |