Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryResult
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Histogram result that matches HistogramQuery specified in searches.
Instance Attribute Summary collapse
-
#histogram ⇒ Hash<String,Fixnum>
A map from the values of the facet associated with distinct values to the number of matching entries with corresponding value.
-
#histogram_query ⇒ String
Requested histogram expression.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1HistogramQueryResult
constructor
A new instance of GoogleCloudContentwarehouseV1HistogramQueryResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1HistogramQueryResult
Returns a new instance of GoogleCloudContentwarehouseV1HistogramQueryResult.
1989 1990 1991 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#histogram ⇒ Hash<String,Fixnum>
A map from the values of the facet associated with distinct values to the
number of matching entries with corresponding value. The key format is: * (for
string histogram) string values stored in the field.
Corresponds to the JSON property histogram
1982 1983 1984 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1982 def histogram @histogram end |
#histogram_query ⇒ String
Requested histogram expression.
Corresponds to the JSON property histogramQuery
1987 1988 1989 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1987 def histogram_query @histogram_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1994 1995 1996 1997 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 1994 def update!(**args) @histogram = args[:histogram] if args.key?(:histogram) @histogram_query = args[:histogram_query] if args.key?(:histogram_query) end |