Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1IngestPipelineConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1IngestPipelineConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
The ingestion pipeline config.
Instance Attribute Summary collapse
-
#cloud_function ⇒ String
The Cloud Function resource name.
-
#document_acl_policy ⇒ Google::Apis::ContentwarehouseV1::GoogleIamV1Policy
An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources.
-
#enable_document_text_extraction ⇒ Boolean
(also: #enable_document_text_extraction?)
The document text extraction enabled flag.
-
#folder ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1IngestPipelineConfig
constructor
A new instance of GoogleCloudContentwarehouseV1IngestPipelineConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1IngestPipelineConfig
Returns a new instance of GoogleCloudContentwarehouseV1IngestPipelineConfig.
2065 2066 2067 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_function ⇒ String
The Cloud Function resource name. The Cloud Function needs to live inside
consumer project and is accessible to Document AI Warehouse P4SA. Only Cloud
Functions V2 is supported. Cloud function execution should complete within 5
minutes or this file ingestion may fail due to timeout. Format: https://
region-project_id.cloudfunctions.net/cloud_function`The following keys
are available the request json payload. * display_name * properties *
plain_text * reference_id * document_schema_name * raw_document_path *
raw_document_file_type The following keys from the cloud function json
response payload will be ingested to the Document AI Warehouse as part of
Document proto content and/or related information. The original values will be
overridden if any key is present in the response. * display_name * properties *
plain_text * document_acl_policy * folder
Corresponds to the JSON propertycloudFunction`
2018 2019 2020 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2018 def cloud_function @cloud_function end |
#document_acl_policy ⇒ Google::Apis::ContentwarehouseV1::GoogleIamV1Policy
An Identity and Access Management (IAM) policy, which specifies access
controls for Google Cloud resources. A Policy is a collection of bindings.
A binding binds one or more members, or principals, to a single role.
Principals can be user accounts, service accounts, Google groups, and domains (
such as G Suite). A role is a named list of permissions; each role can be
an IAM predefined role or a user-created custom role. For some types of Google
Cloud resources, a binding can also specify a condition, which is a
logical expression that allows access to a resource only if the expression
evaluates to true. A condition can add constraints based on attributes of
the request, the resource, or both. To learn which resources support
conditions in their IAM policies, see the IAM documentation. JSON example: ` "
bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [
"user:mike@example.com", "group:admins@example.com", "domain:google.com", "
serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": "
roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com"
], "condition": ` "title": "expirable access", "description": "Does not grant
access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:
00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` YAML
example: bindings: - members: - user:mike@example.com - group:admins@
example.com - domain:google.com - serviceAccount:my-project-id@appspot.
gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: -
user:eve@example.com role: roles/resourcemanager.organizationViewer condition:
title: expirable access description: Does not grant access after Sep 2020
expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag:
BwWWja0YfJA= version: 3 For a description of IAM and its features, see the
IAM documentation.
Corresponds to the JSON property documentAclPolicy
2049 2050 2051 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2049 def document_acl_policy @document_acl_policy end |
#enable_document_text_extraction ⇒ Boolean Also known as: enable_document_text_extraction?
The document text extraction enabled flag. If the flag is set to true, DWH
will perform text extraction on the raw document.
Corresponds to the JSON property enableDocumentTextExtraction
2055 2056 2057 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2055 def enable_document_text_extraction @enable_document_text_extraction end |
#folder ⇒ String
Optional. The name of the folder to which all ingested documents will be
linked during ingestion process. Format is projects/project/locations/
location/documents/folder_id`
Corresponds to the JSON propertyfolder`
2063 2064 2065 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2063 def folder @folder end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2070 2071 2072 2073 2074 2075 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2070 def update!(**args) @cloud_function = args[:cloud_function] if args.key?(:cloud_function) @document_acl_policy = args[:document_acl_policy] if args.key?(:document_acl_policy) @enable_document_text_extraction = args[:enable_document_text_extraction] if args.key?(:enable_document_text_extraction) @folder = args[:folder] if args.key?(:folder) end |