Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1InitializeProjectRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1InitializeProjectRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Request message for projectService.InitializeProject
Instance Attribute Summary collapse
-
#access_control_mode ⇒ String
Required.
-
#database_type ⇒ String
Required.
-
#document_creator_default_role ⇒ String
Optional.
-
#enable_cal_user_email_logging ⇒ Boolean
(also: #enable_cal_user_email_logging?)
Optional.
-
#kms_key ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1InitializeProjectRequest
constructor
A new instance of GoogleCloudContentwarehouseV1InitializeProjectRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1InitializeProjectRequest
Returns a new instance of GoogleCloudContentwarehouseV1InitializeProjectRequest.
2111 2112 2113 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_control_mode ⇒ String
Required. The access control mode for accessing the customer data
Corresponds to the JSON property accessControlMode
2085 2086 2087 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2085 def access_control_mode @access_control_mode end |
#database_type ⇒ String
Required. The type of database used to store customer data
Corresponds to the JSON property databaseType
2090 2091 2092 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2090 def database_type @database_type end |
#document_creator_default_role ⇒ String
Optional. The default role for the person who create a document.
Corresponds to the JSON property documentCreatorDefaultRole
2095 2096 2097 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2095 def document_creator_default_role @document_creator_default_role end |
#enable_cal_user_email_logging ⇒ Boolean Also known as: enable_cal_user_email_logging?
Optional. Whether to enable CAL user email logging.
Corresponds to the JSON property enableCalUserEmailLogging
2100 2101 2102 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2100 def enable_cal_user_email_logging @enable_cal_user_email_logging end |
#kms_key ⇒ String
Optional. The KMS key used for CMEK encryption. It is required that the kms
key is in the same region as the endpoint. The same key will be used for all
provisioned resources, if encryption is available. If the kms_key is left
empty, no encryption will be enforced.
Corresponds to the JSON property kmsKey
2109 2110 2111 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2109 def kms_key @kms_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2116 2117 2118 2119 2120 2121 2122 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2116 def update!(**args) @access_control_mode = args[:access_control_mode] if args.key?(:access_control_mode) @database_type = args[:database_type] if args.key?(:database_type) @document_creator_default_role = args[:document_creator_default_role] if args.key?(:document_creator_default_role) @enable_cal_user_email_logging = args[:enable_cal_user_email_logging] if args.key?(:enable_cal_user_email_logging) @kms_key = args[:kms_key] if args.key?(:kms_key) end |