Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedSourcesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ListLinkedSourcesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Response message for DocumentLinkService.ListLinkedSources.
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
The maximum number of document-links to return.
-
#page_token ⇒ String
A page token, received from a previous
ListLinkedSourcescall. -
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1ListLinkedSourcesRequest
constructor
A new instance of GoogleCloudContentwarehouseV1ListLinkedSourcesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1ListLinkedSourcesRequest
Returns a new instance of GoogleCloudContentwarehouseV1ListLinkedSourcesRequest.
2257 2258 2259 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
The maximum number of document-links to return. The service may return fewer
than this value. If unspecified, at most 50 document-links will be returned.
The maximum value is 1000; values above 1000 will be coerced to 1000.
Corresponds to the JSON property pageSize
2242 2243 2244 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2242 def page_size @page_size end |
#page_token ⇒ String
A page token, received from a previous ListLinkedSources call. Provide this
to retrieve the subsequent page. When paginating, all other parameters
provided to ListLinkedSources must match the call that provided the page
token.
Corresponds to the JSON property pageToken
2250 2251 2252 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2250 def page_token @page_token end |
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
Corresponds to the JSON property requestMetadata
2255 2256 2257 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2255 def @request_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2262 2263 2264 2265 2266 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2262 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @request_metadata = args[:request_metadata] if args.key?(:request_metadata) end |