Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1MapProperty
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1MapProperty
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Map property value. Represents a structured entries of key value pairs, consisting of field names which map to dynamically typed values.
Instance Attribute Summary collapse
-
#fields ⇒ Hash<String,Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Value>
Unordered map of dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1MapProperty
constructor
A new instance of GoogleCloudContentwarehouseV1MapProperty.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1MapProperty
Returns a new instance of GoogleCloudContentwarehouseV1MapProperty.
2427 2428 2429 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fields ⇒ Hash<String,Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Value>
Unordered map of dynamically typed values.
Corresponds to the JSON property fields
2425 2426 2427 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2425 def fields @fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2432 2433 2434 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2432 def update!(**args) @fields = args[:fields] if args.key?(:fields) end |