Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProjectStatus
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProjectStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Status of a project, including the project state, dbType, aclMode and etc.
Instance Attribute Summary collapse
-
#access_control_mode ⇒ String
Access control mode.
-
#database_type ⇒ String
Database type.
-
#document_creator_default_role ⇒ String
The default role for the person who create a document.
-
#location ⇒ String
The location of the queried project.
-
#qa_enabled ⇒ Boolean
(also: #qa_enabled?)
If the qa is enabled on this project.
-
#state ⇒ String
State of the project.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1ProjectStatus
constructor
A new instance of GoogleCloudContentwarehouseV1ProjectStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1ProjectStatus
Returns a new instance of GoogleCloudContentwarehouseV1ProjectStatus.
2597 2598 2599 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2597 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_control_mode ⇒ String
Access control mode.
Corresponds to the JSON property accessControlMode
2569 2570 2571 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2569 def access_control_mode @access_control_mode end |
#database_type ⇒ String
Database type.
Corresponds to the JSON property databaseType
2574 2575 2576 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2574 def database_type @database_type end |
#document_creator_default_role ⇒ String
The default role for the person who create a document.
Corresponds to the JSON property documentCreatorDefaultRole
2579 2580 2581 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2579 def document_creator_default_role @document_creator_default_role end |
#location ⇒ String
The location of the queried project.
Corresponds to the JSON property location
2584 2585 2586 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2584 def location @location end |
#qa_enabled ⇒ Boolean Also known as: qa_enabled?
If the qa is enabled on this project.
Corresponds to the JSON property qaEnabled
2589 2590 2591 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2589 def qa_enabled @qa_enabled end |
#state ⇒ String
State of the project.
Corresponds to the JSON property state
2595 2596 2597 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2595 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2602 2603 2604 2605 2606 2607 2608 2609 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2602 def update!(**args) @access_control_mode = args[:access_control_mode] if args.key?(:access_control_mode) @database_type = args[:database_type] if args.key?(:database_type) @document_creator_default_role = args[:document_creator_default_role] if args.key?(:document_creator_default_role) @location = args[:location] if args.key?(:location) @qa_enabled = args[:qa_enabled] if args.key?(:qa_enabled) @state = args[:state] if args.key?(:state) end |