Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyDefinition
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyDefinition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Defines the metadata for a schema property.
Instance Attribute Summary collapse
-
#date_time_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DateTimeTypeOptions
Configurations for a date time property.
-
#display_name ⇒ String
The display-name for the property, used for front-end.
-
#enum_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1EnumTypeOptions
Configurations for an enum/categorical property.
-
#float_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FloatTypeOptions
Configurations for a float property.
-
#integer_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1IntegerTypeOptions
Configurations for an integer property.
-
#is_filterable ⇒ Boolean
(also: #is_filterable?)
Whether the property can be filtered.
-
#is_metadata ⇒ Boolean
(also: #is_metadata?)
Whether the property is user supplied metadata.
-
#is_repeatable ⇒ Boolean
(also: #is_repeatable?)
Whether the property can have multiple values.
-
#is_required ⇒ Boolean
(also: #is_required?)
Whether the property is mandatory.
-
#is_searchable ⇒ Boolean
(also: #is_searchable?)
Indicates that the property should be included in a global search.
-
#map_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1MapTypeOptions
Configurations for a Map property.
-
#name ⇒ String
Required.
-
#property_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyTypeOptions
Configurations for a nested structured data property.
-
#retrieval_importance ⇒ String
The retrieval importance of the property during search.
-
#schema_sources ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyDefinitionSchemaSource>
The mapping information between this property to another schema source.
-
#text_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TextTypeOptions
Configurations for a text property.
-
#timestamp_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampTypeOptions
Configurations for a timestamp property.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1PropertyDefinition
constructor
A new instance of GoogleCloudContentwarehouseV1PropertyDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1PropertyDefinition
Returns a new instance of GoogleCloudContentwarehouseV1PropertyDefinition.
2800 2801 2802 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2800 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date_time_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1DateTimeTypeOptions
Configurations for a date time property.
Corresponds to the JSON property dateTimeTypeOptions
2706 2707 2708 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2706 def @date_time_type_options end |
#display_name ⇒ String
The display-name for the property, used for front-end.
Corresponds to the JSON property displayName
2711 2712 2713 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2711 def display_name @display_name end |
#enum_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1EnumTypeOptions
Configurations for an enum/categorical property.
Corresponds to the JSON property enumTypeOptions
2716 2717 2718 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2716 def @enum_type_options end |
#float_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1FloatTypeOptions
Configurations for a float property.
Corresponds to the JSON property floatTypeOptions
2721 2722 2723 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2721 def @float_type_options end |
#integer_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1IntegerTypeOptions
Configurations for an integer property.
Corresponds to the JSON property integerTypeOptions
2726 2727 2728 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2726 def @integer_type_options end |
#is_filterable ⇒ Boolean Also known as: is_filterable?
Whether the property can be filtered. If this is a sub-property, all the
parent properties must be marked filterable.
Corresponds to the JSON property isFilterable
2732 2733 2734 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2732 def is_filterable @is_filterable end |
#is_metadata ⇒ Boolean Also known as: is_metadata?
Whether the property is user supplied metadata. This out-of-the box
placeholder setting can be used to tag derived properties. Its value and
interpretation logic should be implemented by API user.
Corresponds to the JSON property isMetadata
2740 2741 2742 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2740 def @is_metadata end |
#is_repeatable ⇒ Boolean Also known as: is_repeatable?
Whether the property can have multiple values.
Corresponds to the JSON property isRepeatable
2746 2747 2748 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2746 def is_repeatable @is_repeatable end |
#is_required ⇒ Boolean Also known as: is_required?
Whether the property is mandatory. Default is 'false', i.e. populating
property value can be skipped. If 'true' then user must populate the value for
this property.
Corresponds to the JSON property isRequired
2754 2755 2756 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2754 def is_required @is_required end |
#is_searchable ⇒ Boolean Also known as: is_searchable?
Indicates that the property should be included in a global search.
Corresponds to the JSON property isSearchable
2760 2761 2762 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2760 def is_searchable @is_searchable end |
#map_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1MapTypeOptions
Configurations for a Map property.
Corresponds to the JSON property mapTypeOptions
2766 2767 2768 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2766 def @map_type_options end |
#name ⇒ String
Required. The name of the metadata property. Must be unique within a document
schema and is case insensitive. Names must be non-blank, start with a letter,
and can contain alphanumeric characters and: /, :, -, _, and .
Corresponds to the JSON property name
2773 2774 2775 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2773 def name @name end |
#property_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyTypeOptions
Configurations for a nested structured data property.
Corresponds to the JSON property propertyTypeOptions
2778 2779 2780 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2778 def @property_type_options end |
#retrieval_importance ⇒ String
The retrieval importance of the property during search.
Corresponds to the JSON property retrievalImportance
2783 2784 2785 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2783 def retrieval_importance @retrieval_importance end |
#schema_sources ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1PropertyDefinitionSchemaSource>
The mapping information between this property to another schema source.
Corresponds to the JSON property schemaSources
2788 2789 2790 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2788 def schema_sources @schema_sources end |
#text_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TextTypeOptions
Configurations for a text property.
Corresponds to the JSON property textTypeOptions
2793 2794 2795 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2793 def @text_type_options end |
#timestamp_type_options ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampTypeOptions
Configurations for a timestamp property.
Corresponds to the JSON property timestampTypeOptions
2798 2799 2800 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2798 def @timestamp_type_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 2805 def update!(**args) @date_time_type_options = args[:date_time_type_options] if args.key?(:date_time_type_options) @display_name = args[:display_name] if args.key?(:display_name) @enum_type_options = args[:enum_type_options] if args.key?(:enum_type_options) @float_type_options = args[:float_type_options] if args.key?(:float_type_options) @integer_type_options = args[:integer_type_options] if args.key?(:integer_type_options) @is_filterable = args[:is_filterable] if args.key?(:is_filterable) @is_metadata = args[:is_metadata] if args.key?(:is_metadata) @is_repeatable = args[:is_repeatable] if args.key?(:is_repeatable) @is_required = args[:is_required] if args.key?(:is_required) @is_searchable = args[:is_searchable] if args.key?(:is_searchable) @map_type_options = args[:map_type_options] if args.key?(:map_type_options) @name = args[:name] if args.key?(:name) @property_type_options = args[:property_type_options] if args.key?(:property_type_options) @retrieval_importance = args[:retrieval_importance] if args.key?(:retrieval_importance) @schema_sources = args[:schema_sources] if args.key?(:schema_sources) @text_type_options = args[:text_type_options] if args.key?(:text_type_options) @timestamp_type_options = args[:timestamp_type_options] if args.key?(:timestamp_type_options) end |