Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEngineOutput
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEngineOutput
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Records the output of Rule Engine including rule evaluation and actions result.
Instance Attribute Summary collapse
-
#action_executor_output ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ActionExecutorOutput
Represents the output of the Action Executor.
-
#document_name ⇒ String
Name of the document against which the rules and actions were evaluated.
-
#rule_evaluator_output ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEvaluatorOutput
Represents the output of the Rule Evaluator.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RuleEngineOutput
constructor
A new instance of GoogleCloudContentwarehouseV1RuleEngineOutput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RuleEngineOutput
Returns a new instance of GoogleCloudContentwarehouseV1RuleEngineOutput.
3151 3152 3153 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_executor_output ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ActionExecutorOutput
Represents the output of the Action Executor.
Corresponds to the JSON property actionExecutorOutput
3139 3140 3141 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3139 def action_executor_output @action_executor_output end |
#document_name ⇒ String
Name of the document against which the rules and actions were evaluated.
Corresponds to the JSON property documentName
3144 3145 3146 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3144 def document_name @document_name end |
#rule_evaluator_output ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEvaluatorOutput
Represents the output of the Rule Evaluator.
Corresponds to the JSON property ruleEvaluatorOutput
3149 3150 3151 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3149 def rule_evaluator_output @rule_evaluator_output end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3156 3157 3158 3159 3160 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3156 def update!(**args) @action_executor_output = args[:action_executor_output] if args.key?(:action_executor_output) @document_name = args[:document_name] if args.key?(:document_name) @rule_evaluator_output = args[:rule_evaluator_output] if args.key?(:rule_evaluator_output) end |