Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataIndividualDocumentStatus
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineMetadataIndividualDocumentStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
The status of processing a document.
Instance Attribute Summary collapse
-
#document_id ⇒ String
Document identifier of an existing document.
-
#status ⇒ Google::Apis::ContentwarehouseV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RunPipelineMetadataIndividualDocumentStatus
constructor
A new instance of GoogleCloudContentwarehouseV1RunPipelineMetadataIndividualDocumentStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RunPipelineMetadataIndividualDocumentStatus
Returns a new instance of GoogleCloudContentwarehouseV1RunPipelineMetadataIndividualDocumentStatus.
3357 3358 3359 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_id ⇒ String
Document identifier of an existing document.
Corresponds to the JSON property documentId
3345 3346 3347 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3345 def document_id @document_id end |
#status ⇒ Google::Apis::ContentwarehouseV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
3355 3356 3357 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3355 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3362 3363 3364 3365 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3362 def update!(**args) @document_id = args[:document_id] if args.key?(:document_id) @status = args[:status] if args.key?(:status) end |