Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RunPipelineRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Request message for DocumentService.RunPipeline.
Instance Attribute Summary collapse
-
#export_cdw_pipeline ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ExportToCdwPipeline
The configuration of exporting documents from the Document Warehouse to CDW pipeline.
-
#gcs_ingest_pipeline ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GcsIngestPipeline
The configuration of the Cloud Storage Ingestion pipeline.
-
#gcs_ingest_with_doc_ai_processors_pipeline ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GcsIngestWithDocAiProcessorsPipeline
The configuration of the Cloud Storage Ingestion with DocAI Processors pipeline.
-
#process_with_doc_ai_pipeline ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProcessWithDocAiPipeline
The configuration of processing documents in Document Warehouse with DocAi processors pipeline.
-
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RunPipelineRequest
constructor
A new instance of GoogleCloudContentwarehouseV1RunPipelineRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1RunPipelineRequest
Returns a new instance of GoogleCloudContentwarehouseV1RunPipelineRequest.
3425 3426 3427 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_cdw_pipeline ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ExportToCdwPipeline
The configuration of exporting documents from the Document Warehouse to CDW
pipeline.
Corresponds to the JSON property exportCdwPipeline
3401 3402 3403 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3401 def export_cdw_pipeline @export_cdw_pipeline end |
#gcs_ingest_pipeline ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GcsIngestPipeline
The configuration of the Cloud Storage Ingestion pipeline.
Corresponds to the JSON property gcsIngestPipeline
3406 3407 3408 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3406 def gcs_ingest_pipeline @gcs_ingest_pipeline end |
#gcs_ingest_with_doc_ai_processors_pipeline ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1GcsIngestWithDocAiProcessorsPipeline
The configuration of the Cloud Storage Ingestion with DocAI Processors
pipeline.
Corresponds to the JSON property gcsIngestWithDocAiProcessorsPipeline
3412 3413 3414 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3412 def gcs_ingest_with_doc_ai_processors_pipeline @gcs_ingest_with_doc_ai_processors_pipeline end |
#process_with_doc_ai_pipeline ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ProcessWithDocAiPipeline
The configuration of processing documents in Document Warehouse with DocAi
processors pipeline.
Corresponds to the JSON property processWithDocAiPipeline
3418 3419 3420 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3418 def process_with_doc_ai_pipeline @process_with_doc_ai_pipeline end |
#request_metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RequestMetadata
Meta information is used to improve the performance of the service.
Corresponds to the JSON property requestMetadata
3423 3424 3425 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3423 def @request_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3430 3431 3432 3433 3434 3435 3436 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3430 def update!(**args) @export_cdw_pipeline = args[:export_cdw_pipeline] if args.key?(:export_cdw_pipeline) @gcs_ingest_pipeline = args[:gcs_ingest_pipeline] if args.key?(:gcs_ingest_pipeline) @gcs_ingest_with_doc_ai_processors_pipeline = args[:gcs_ingest_with_doc_ai_processors_pipeline] if args.key?(:gcs_ingest_with_doc_ai_processors_pipeline) @process_with_doc_ai_pipeline = args[:process_with_doc_ai_pipeline] if args.key?(:process_with_doc_ai_pipeline) @request_metadata = args[:request_metadata] if args.key?(:request_metadata) end |