Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Response message for DocumentService.SearchDocuments.
Instance Attribute Summary collapse
-
#histogram_query_results ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryResult>
The histogram results that match with the specified SearchDocumentsRequest.
-
#matching_documents ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsResponseMatchingDocument>
The document entities that match the specified SearchDocumentsRequest.
-
#metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata
Additional information returned to client, such as debugging information.
-
#next_page_token ⇒ String
The token that specifies the starting position of the next page of results.
-
#question_answer ⇒ String
Experimental.
-
#total_size ⇒ Fixnum
The total number of matched documents which is available only if the client set SearchDocumentsRequest.require_total_size to
trueor set SearchDocumentsRequest.total_result_size toESTIMATED_SIZEorACTUAL_SIZE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1SearchDocumentsResponse
constructor
A new instance of GoogleCloudContentwarehouseV1SearchDocumentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1SearchDocumentsResponse
Returns a new instance of GoogleCloudContentwarehouseV1SearchDocumentsResponse.
3592 3593 3594 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#histogram_query_results ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1HistogramQueryResult>
The histogram results that match with the specified SearchDocumentsRequest.
histogram_queries.
Corresponds to the JSON property histogramQueryResults
3560 3561 3562 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3560 def histogram_query_results @histogram_query_results end |
#matching_documents ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SearchDocumentsResponseMatchingDocument>
The document entities that match the specified SearchDocumentsRequest.
Corresponds to the JSON property matchingDocuments
3565 3566 3567 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3565 def matching_documents @matching_documents end |
#metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata
Additional information returned to client, such as debugging information.
Corresponds to the JSON property metadata
3570 3571 3572 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3570 def @metadata end |
#next_page_token ⇒ String
The token that specifies the starting position of the next page of results.
This field is empty if there are no more results.
Corresponds to the JSON property nextPageToken
3576 3577 3578 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3576 def next_page_token @next_page_token end |
#question_answer ⇒ String
Experimental. Question answer from the query against the document.
Corresponds to the JSON property questionAnswer
3581 3582 3583 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3581 def question_answer @question_answer end |
#total_size ⇒ Fixnum
The total number of matched documents which is available only if the client
set SearchDocumentsRequest.require_total_size to true or set
SearchDocumentsRequest.total_result_size to ESTIMATED_SIZE or ACTUAL_SIZE.
Otherwise, the value will be -1. Typically a UI would handle this condition
by displaying "of many", for example: "Displaying 10 of many".
Corresponds to the JSON property totalSize
3590 3591 3592 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3590 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3597 3598 3599 3600 3601 3602 3603 3604 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3597 def update!(**args) @histogram_query_results = args[:histogram_query_results] if args.key?(:histogram_query_results) @matching_documents = args[:matching_documents] if args.key?(:matching_documents) @metadata = args[:metadata] if args.key?(:metadata) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @question_answer = args[:question_answer] if args.key?(:question_answer) @total_size = args[:total_size] if args.key?(:total_size) end |