Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSetSynonym
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1SynonymSetSynonym
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents a list of words given by the customer All these words are synonyms of each other.
Instance Attribute Summary collapse
-
#words ⇒ Array<String>
For example: sale, invoice, bill, order Corresponds to the JSON property
words.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1SynonymSetSynonym
constructor
A new instance of GoogleCloudContentwarehouseV1SynonymSetSynonym.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1SynonymSetSynonym
Returns a new instance of GoogleCloudContentwarehouseV1SynonymSetSynonym.
3808 3809 3810 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3808 def initialize(**args) update!(**args) end |
Instance Attribute Details
#words ⇒ Array<String>
For example: sale, invoice, bill, order
Corresponds to the JSON property words
3806 3807 3808 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3806 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3813 3814 3815 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3813 def update!(**args) @words = args[:words] if args.key?(:words) end |