Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UpdateDocumentResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Response message for DocumentService.UpdateDocument.
Instance Attribute Summary collapse
-
#document ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Defines the structure for content warehouse document proto.
-
#metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata
Additional information returned to client, such as debugging information.
-
#rule_engine_output ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEngineOutput
Records the output of Rule Engine including rule evaluation and actions result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1UpdateDocumentResponse
constructor
A new instance of GoogleCloudContentwarehouseV1UpdateDocumentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1UpdateDocumentResponse
Returns a new instance of GoogleCloudContentwarehouseV1UpdateDocumentResponse.
4006 4007 4008 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Document
Defines the structure for content warehouse document proto.
Corresponds to the JSON property document
3994 3995 3996 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3994 def document @document end |
#metadata ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1ResponseMetadata
Additional information returned to client, such as debugging information.
Corresponds to the JSON property metadata
3999 4000 4001 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 3999 def @metadata end |
#rule_engine_output ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1RuleEngineOutput
Records the output of Rule Engine including rule evaluation and actions result.
Corresponds to the JSON property ruleEngineOutput
4004 4005 4006 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4004 def rule_engine_output @rule_engine_output end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4011 4012 4013 4014 4015 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4011 def update!(**args) @document = args[:document] if args.key?(:document) @metadata = args[:metadata] if args.key?(:metadata) @rule_engine_output = args[:rule_engine_output] if args.key?(:rule_engine_output) end |