Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UserInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1UserInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
The user information.
Instance Attribute Summary collapse
-
#group_ids ⇒ Array<String>
The unique group identifications which the user is belong to.
-
#id ⇒ String
A unique user identification string, as determined by the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1UserInfo
constructor
A new instance of GoogleCloudContentwarehouseV1UserInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1UserInfo
Returns a new instance of GoogleCloudContentwarehouseV1UserInfo.
4107 4108 4109 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group_ids ⇒ Array<String>
The unique group identifications which the user is belong to. The format is "
group:yyyy@example.com";
Corresponds to the JSON property groupIds
4097 4098 4099 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4097 def group_ids @group_ids end |
#id ⇒ String
A unique user identification string, as determined by the client. The maximum
number of allowed characters is 255. Allowed characters include numbers 0 to 9,
uppercase and lowercase letters, and restricted special symbols (:, @, +, -,
_, ~) The format is "user:xxxx@example.com";
Corresponds to the JSON property id
4105 4106 4107 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4105 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4112 4113 4114 4115 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4112 def update!(**args) @group_ids = args[:group_ids] if args.key?(:group_ids) @id = args[:id] if args.key?(:id) end |