Class: Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Value
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1Value
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Value represents a dynamically typed value which can be either be a float, a
integer, a string, or a datetime value. A producer of value is expected to set
one of these variants. Absence of any variant indicates an error.
Instance Attribute Summary collapse
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
Represents a boolean value.
-
#datetime_value ⇒ Google::Apis::ContentwarehouseV1::GoogleTypeDateTime
Represents civil time (or occasionally physical time).
-
#enum_value ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1EnumValue
Represents the string value of the enum field.
-
#float_value ⇒ Float
Represents a float value.
-
#int_value ⇒ Fixnum
Represents a integer value.
-
#string_value ⇒ String
Represents a string value.
-
#timestamp_value ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampValue
Timestamp value type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1Value
constructor
A new instance of GoogleCloudContentwarehouseV1Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudContentwarehouseV1Value
Returns a new instance of GoogleCloudContentwarehouseV1Value.
4173 4174 4175 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_value ⇒ Boolean Also known as: boolean_value?
Represents a boolean value.
Corresponds to the JSON property booleanValue
4127 4128 4129 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4127 def boolean_value @boolean_value end |
#datetime_value ⇒ Google::Apis::ContentwarehouseV1::GoogleTypeDateTime
Represents civil time (or occasionally physical time). This type can represent
a civil time in one of a few possible ways: * When utc_offset is set and
time_zone is unset: a civil time on a calendar day with a particular offset
from UTC. * When time_zone is set and utc_offset is unset: a civil time on a
calendar day in a particular time zone. * When neither time_zone nor
utc_offset is set: a civil time on a calendar day in local time. The date is
relative to the Proleptic Gregorian Calendar. If year, month, or day are 0,
the DateTime is considered not to have a specific year, month, or day
respectively. This type may also be used to represent a physical time if all
the date and time fields are set and either case of the time_offset oneof is
set. Consider using Timestamp message for physical time instead. If your use
case also would like to store the user's timezone, that can be done in another
field. This type is more flexible than some applications may want. Make sure
to document and validate your application's limitations.
Corresponds to the JSON property datetimeValue
4146 4147 4148 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4146 def datetime_value @datetime_value end |
#enum_value ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1EnumValue
Represents the string value of the enum field.
Corresponds to the JSON property enumValue
4151 4152 4153 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4151 def enum_value @enum_value end |
#float_value ⇒ Float
Represents a float value.
Corresponds to the JSON property floatValue
4156 4157 4158 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4156 def float_value @float_value end |
#int_value ⇒ Fixnum
Represents a integer value.
Corresponds to the JSON property intValue
4161 4162 4163 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4161 def int_value @int_value end |
#string_value ⇒ String
Represents a string value.
Corresponds to the JSON property stringValue
4166 4167 4168 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4166 def string_value @string_value end |
#timestamp_value ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudContentwarehouseV1TimestampValue
Timestamp value type.
Corresponds to the JSON property timestampValue
4171 4172 4173 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4171 def @timestamp_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4178 4179 4180 4181 4182 4183 4184 4185 4186 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4178 def update!(**args) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @datetime_value = args[:datetime_value] if args.key?(:datetime_value) @enum_value = args[:enum_value] if args.key?(:enum_value) @float_value = args[:float_value] if args.key?(:float_value) @int_value = args[:int_value] if args.key?(:int_value) @string_value = args[:string_value] if args.key?(:string_value) @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value) end |