Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1Document
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1Document
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality.
Instance Attribute Summary collapse
-
#chunked_document ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentChunkedDocument
Represents the chunks that the document is divided into.
-
#content ⇒ String
Optional.
-
#document_layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayout
Represents the parsed layout of a document as a collection of blocks that the document is divided into.
-
#entities ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntity>
A list of entities detected on Document.text.
-
#entity_relations ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntityRelation>
Placeholder.
-
#error ⇒ Google::Apis::ContentwarehouseV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#mime_type ⇒ String
An IANA published media type (MIME type).
-
#pages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPage>
Visual page layout for the Document.
-
#revisions ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentRevision>
Placeholder.
-
#shard_info ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentShardInfo
For a large document, sharding may be performed to produce several document shards.
-
#text ⇒ String
Optional.
-
#text_changes ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextChange>
Placeholder.
-
#text_styles ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentStyle>
Styles for the Document.text.
-
#uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1Document
constructor
A new instance of GoogleCloudDocumentaiV1Document.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1Document
Returns a new instance of GoogleCloudDocumentaiV1Document.
4426 4427 4428 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunked_document ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentChunkedDocument
Represents the chunks that the document is divided into.
Corresponds to the JSON property chunkedDocument
4342 4343 4344 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4342 def chunked_document @chunked_document end |
#content ⇒ String
Optional. Inline document content, represented as a stream of bytes. Note: As
with all bytes fields, protobuffers use a pure binary representation,
whereas JSON representations use base64.
Corresponds to the JSON property content
NOTE: Values are automatically base64 encoded/decoded in the client library.
4350 4351 4352 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4350 def content @content end |
#document_layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayout
Represents the parsed layout of a document as a collection of blocks that the
document is divided into.
Corresponds to the JSON property documentLayout
4356 4357 4358 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4356 def document_layout @document_layout end |
#entities ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntity>
A list of entities detected on Document.text. For document shards, entities in
this list may cross shard boundaries.
Corresponds to the JSON property entities
4362 4363 4364 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4362 def entities @entities end |
#entity_relations ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentEntityRelation>
Placeholder. Relationship among Document.entities.
Corresponds to the JSON property entityRelations
4367 4368 4369 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4367 def entity_relations @entity_relations end |
#error ⇒ Google::Apis::ContentwarehouseV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4377 4378 4379 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4377 def error @error end |
#mime_type ⇒ String
An IANA published media type (MIME type).
Corresponds to the JSON property mimeType
4383 4384 4385 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4383 def mime_type @mime_type end |
#pages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPage>
Visual page layout for the Document.
Corresponds to the JSON property pages
4388 4389 4390 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4388 def pages @pages end |
#revisions ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentRevision>
Placeholder. Revision history of this document.
Corresponds to the JSON property revisions
4393 4394 4395 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4393 def revisions @revisions end |
#shard_info ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentShardInfo
For a large document, sharding may be performed to produce several document
shards. Each document shard contains this field to detail which shard it is.
Corresponds to the JSON property shardInfo
4399 4400 4401 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4399 def shard_info @shard_info end |
#text ⇒ String
Optional. UTF-8 encoded text in reading order from the document.
Corresponds to the JSON property text
4404 4405 4406 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4404 def text @text end |
#text_changes ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentTextChange>
Placeholder. A list of text corrections made to Document.text. This is usually
used for annotating corrections to OCR mistakes. Text changes for a given
revision may not overlap with each other.
Corresponds to the JSON property textChanges
4411 4412 4413 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4411 def text_changes @text_changes end |
#text_styles ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentStyle>
Styles for the Document.text.
Corresponds to the JSON property textStyles
4416 4417 4418 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4416 def text_styles @text_styles end |
#uri ⇒ String
Optional. Currently supports Google Cloud Storage URI of the form gs://
bucket_name/object_name. Object versioning is not supported. For more
information, refer to Google Cloud Storage Request URIs.
Corresponds to the JSON property uri
4424 4425 4426 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4424 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4431 4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4431 def update!(**args) @chunked_document = args[:chunked_document] if args.key?(:chunked_document) @content = args[:content] if args.key?(:content) @document_layout = args[:document_layout] if args.key?(:document_layout) @entities = args[:entities] if args.key?(:entities) @entity_relations = args[:entity_relations] if args.key?(:entity_relations) @error = args[:error] if args.key?(:error) @mime_type = args[:mime_type] if args.key?(:mime_type) @pages = args[:pages] if args.key?(:pages) @revisions = args[:revisions] if args.key?(:revisions) @shard_info = args[:shard_info] if args.key?(:shard_info) @text = args[:text] if args.key?(:text) @text_changes = args[:text_changes] if args.key?(:text_changes) @text_styles = args[:text_styles] if args.key?(:text_styles) @uri = args[:uri] if args.key?(:uri) end |