Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayout
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayout
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
Represents the parsed layout of a document as a collection of blocks that the document is divided into.
Instance Attribute Summary collapse
-
#blocks ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock>
List of blocks in the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentDocumentLayout
constructor
A new instance of GoogleCloudDocumentaiV1DocumentDocumentLayout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentDocumentLayout
Returns a new instance of GoogleCloudDocumentaiV1DocumentDocumentLayout.
4602 4603 4604 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocks ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock>
List of blocks in the document.
Corresponds to the JSON property blocks
4600 4601 4602 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4600 def blocks @blocks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4607 4608 4609 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 4607 def update!(**args) @blocks = args[:blocks] if args.key?(:blocks) end |