Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageFormField
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageFormField
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
A form field detected on the page.
Instance Attribute Summary collapse
-
#corrected_key_text ⇒ String
Created for Labeling UI to export key text.
-
#corrected_value_text ⇒ String
Created for Labeling UI to export value text.
-
#field_name ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
-
#field_value ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
-
#name_detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages for name together with confidence.
-
#provenance ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in different revisions.
-
#value_detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages for value together with confidence.
-
#value_type ⇒ String
If the value is non-textual, this field represents the type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageFormField
constructor
A new instance of GoogleCloudDocumentaiV1DocumentPageFormField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageFormField
Returns a new instance of GoogleCloudDocumentaiV1DocumentPageFormField.
5415 5416 5417 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corrected_key_text ⇒ String
Created for Labeling UI to export key text. If corrections were made to the
text identified by the field_name.text_anchor, this field will contain the
correction.
Corresponds to the JSON property correctedKeyText
5373 5374 5375 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5373 def corrected_key_text @corrected_key_text end |
#corrected_value_text ⇒ String
Created for Labeling UI to export value text. If corrections were made to the
text identified by the field_value.text_anchor, this field will contain the
correction.
Corresponds to the JSON property correctedValueText
5380 5381 5382 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5380 def corrected_value_text @corrected_value_text end |
#field_name ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property fieldName
5385 5386 5387 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5385 def field_name @field_name end |
#field_value ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property fieldValue
5390 5391 5392 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5390 def field_value @field_value end |
#name_detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages for name together with confidence.
Corresponds to the JSON property nameDetectedLanguages
5395 5396 5397 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5395 def name_detected_languages @name_detected_languages end |
#provenance ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in
different revisions.
Corresponds to the JSON property provenance
5401 5402 5403 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5401 def provenance @provenance end |
#value_detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages for value together with confidence.
Corresponds to the JSON property valueDetectedLanguages
5406 5407 5408 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5406 def value_detected_languages @value_detected_languages end |
#value_type ⇒ String
If the value is non-textual, this field represents the type. Current valid
values are: - blank (this indicates the field_value is normal text) -
unfilled_checkbox - filled_checkbox
Corresponds to the JSON property valueType
5413 5414 5415 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5413 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5420 def update!(**args) @corrected_key_text = args[:corrected_key_text] if args.key?(:corrected_key_text) @corrected_value_text = args[:corrected_value_text] if args.key?(:corrected_value_text) @field_name = args[:field_name] if args.key?(:field_name) @field_value = args[:field_value] if args.key?(:field_value) @name_detected_languages = args[:name_detected_languages] if args.key?(:name_detected_languages) @provenance = args[:provenance] if args.key?(:provenance) @value_detected_languages = args[:value_detected_languages] if args.key?(:value_detected_languages) @value_type = args[:value_type] if args.key?(:value_type) end |