Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageParagraph
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageParagraph
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
A collection of lines that a human would perceive as a paragraph.
Instance Attribute Summary collapse
-
#detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
-
#layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
-
#provenance ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in different revisions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageParagraph
constructor
A new instance of GoogleCloudDocumentaiV1DocumentPageParagraph.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageParagraph
Returns a new instance of GoogleCloudDocumentaiV1DocumentPageParagraph.
5659 5660 5661 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detected_languages ⇒ Array<Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
Corresponds to the JSON property detectedLanguages
5646 5647 5648 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5646 def detected_languages @detected_languages end |
#layout ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property layout
5651 5652 5653 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5651 def layout @layout end |
#provenance ⇒ Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in
different revisions.
Corresponds to the JSON property provenance
5657 5658 5659 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5657 def provenance @provenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5664 5665 5666 5667 5668 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 5664 def update!(**args) @detected_languages = args[:detected_languages] if args.key?(:detected_languages) @layout = args[:layout] if args.key?(:layout) @provenance = args[:provenance] if args.key?(:provenance) end |