Class: Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenanceParent
- Inherits:
-
Object
- Object
- Google::Apis::ContentwarehouseV1::GoogleCloudDocumentaiV1DocumentProvenanceParent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/contentwarehouse_v1/classes.rb,
lib/google/apis/contentwarehouse_v1/representations.rb,
lib/google/apis/contentwarehouse_v1/representations.rb
Overview
The parent element the current element is based on. Used for referencing/ aligning, removal and replacement operations.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The id of the parent provenance.
-
#index ⇒ Fixnum
The index of the parent item in the corresponding item list (eg. list of entities, properties within entities, etc.) in the parent revision.
-
#revision ⇒ Fixnum
The index of the index into current revision's parent_ids list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentProvenanceParent
constructor
A new instance of GoogleCloudDocumentaiV1DocumentProvenanceParent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentProvenanceParent
Returns a new instance of GoogleCloudDocumentaiV1DocumentProvenanceParent.
6149 6150 6151 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The id of the parent provenance.
Corresponds to the JSON property id
6136 6137 6138 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6136 def id @id end |
#index ⇒ Fixnum
The index of the parent item in the corresponding item list (eg. list of
entities, properties within entities, etc.) in the parent revision.
Corresponds to the JSON property index
6142 6143 6144 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6142 def index @index end |
#revision ⇒ Fixnum
The index of the index into current revision's parent_ids list.
Corresponds to the JSON property revision
6147 6148 6149 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6147 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6154 6155 6156 6157 6158 |
# File 'lib/google/apis/contentwarehouse_v1/classes.rb', line 6154 def update!(**args) @id = args[:id] if args.key?(:id) @index = args[:index] if args.key?(:index) @revision = args[:revision] if args.key?(:revision) end |